# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetAutoThrottleRulesResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetAutoThrottleRulesResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message that contains information such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetAutoThrottleRulesResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetAutoThrottleRulesResponseBodyData(DaraModel):
    def __init__(
        self,
        enable_auto_throttle_count: int = None,
        enable_auto_throttle_list: List[main_models.GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList] = None,
        never_enable_auto_throttle_or_released_instance_count: int = None,
        never_enable_auto_throttle_or_released_instance_id_list: List[str] = None,
        total_auto_throttle_rules_count: int = None,
        turn_off_auto_throttle_count: int = None,
        turn_off_auto_throttle_list: List[main_models.GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList] = None,
    ):
        # The number of database instances for which the automatic SQL throttling feature is currently enabled.
        self.enable_auto_throttle_count = enable_auto_throttle_count
        # The database instances for which the automatic SQL throttling feature is currently enabled.
        self.enable_auto_throttle_list = enable_auto_throttle_list
        # The number of database instances that do not exist or for which the automatic SQL throttling feature has never been enabled.
        # 
        # >  If a database instance does not exist, the instance has been released or the specified instance ID is invalid.
        self.never_enable_auto_throttle_or_released_instance_count = never_enable_auto_throttle_or_released_instance_count
        # The number of database instances that do not exist or for which the automatic SQL throttling feature has never been enabled.
        # 
        # >  If a database instance does not exist, the instance has been released or the specified instance ID is invalid.
        self.never_enable_auto_throttle_or_released_instance_id_list = never_enable_auto_throttle_or_released_instance_id_list
        # The number of databases for which the automatic SQL throttling feature has been enabled.
        self.total_auto_throttle_rules_count = total_auto_throttle_rules_count
        # The number of database instances for which the automatic SQL throttling feature was once enabled but is currently disabled.
        self.turn_off_auto_throttle_count = turn_off_auto_throttle_count
        # The database instances for which the automatic SQL throttling feature was once enabled but is currently disabled.
        self.turn_off_auto_throttle_list = turn_off_auto_throttle_list

    def validate(self):
        if self.enable_auto_throttle_list:
            for v1 in self.enable_auto_throttle_list:
                 if v1:
                    v1.validate()
        if self.turn_off_auto_throttle_list:
            for v1 in self.turn_off_auto_throttle_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.enable_auto_throttle_count is not None:
            result['EnableAutoThrottleCount'] = self.enable_auto_throttle_count

        result['EnableAutoThrottleList'] = []
        if self.enable_auto_throttle_list is not None:
            for k1 in self.enable_auto_throttle_list:
                result['EnableAutoThrottleList'].append(k1.to_map() if k1 else None)

        if self.never_enable_auto_throttle_or_released_instance_count is not None:
            result['NeverEnableAutoThrottleOrReleasedInstanceCount'] = self.never_enable_auto_throttle_or_released_instance_count

        if self.never_enable_auto_throttle_or_released_instance_id_list is not None:
            result['NeverEnableAutoThrottleOrReleasedInstanceIdList'] = self.never_enable_auto_throttle_or_released_instance_id_list

        if self.total_auto_throttle_rules_count is not None:
            result['TotalAutoThrottleRulesCount'] = self.total_auto_throttle_rules_count

        if self.turn_off_auto_throttle_count is not None:
            result['TurnOffAutoThrottleCount'] = self.turn_off_auto_throttle_count

        result['TurnOffAutoThrottleList'] = []
        if self.turn_off_auto_throttle_list is not None:
            for k1 in self.turn_off_auto_throttle_list:
                result['TurnOffAutoThrottleList'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('EnableAutoThrottleCount') is not None:
            self.enable_auto_throttle_count = m.get('EnableAutoThrottleCount')

        self.enable_auto_throttle_list = []
        if m.get('EnableAutoThrottleList') is not None:
            for k1 in m.get('EnableAutoThrottleList'):
                temp_model = main_models.GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList()
                self.enable_auto_throttle_list.append(temp_model.from_map(k1))

        if m.get('NeverEnableAutoThrottleOrReleasedInstanceCount') is not None:
            self.never_enable_auto_throttle_or_released_instance_count = m.get('NeverEnableAutoThrottleOrReleasedInstanceCount')

        if m.get('NeverEnableAutoThrottleOrReleasedInstanceIdList') is not None:
            self.never_enable_auto_throttle_or_released_instance_id_list = m.get('NeverEnableAutoThrottleOrReleasedInstanceIdList')

        if m.get('TotalAutoThrottleRulesCount') is not None:
            self.total_auto_throttle_rules_count = m.get('TotalAutoThrottleRulesCount')

        if m.get('TurnOffAutoThrottleCount') is not None:
            self.turn_off_auto_throttle_count = m.get('TurnOffAutoThrottleCount')

        self.turn_off_auto_throttle_list = []
        if m.get('TurnOffAutoThrottleList') is not None:
            for k1 in m.get('TurnOffAutoThrottleList'):
                temp_model = main_models.GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList()
                self.turn_off_auto_throttle_list.append(temp_model.from_map(k1))

        return self

class GetAutoThrottleRulesResponseBodyDataTurnOffAutoThrottleList(DaraModel):
    def __init__(
        self,
        abnormal_duration: float = None,
        active_sessions: int = None,
        allow_throttle_end_time: str = None,
        allow_throttle_start_time: str = None,
        auto_kill_session: bool = None,
        cpu_session_relation: str = None,
        cpu_usage: float = None,
        instance_id: str = None,
        max_throttle_time: float = None,
        user_id: str = None,
        visible: bool = None,
    ):
        # The maximum period of time during which the automatic SQL throttling feature is triggered. Unit: minutes.
        self.abnormal_duration = abnormal_duration
        # The maximum number of active sessions.
        self.active_sessions = active_sessions
        # The end time of the throttling window. The value of this parameter is in UTC.
        self.allow_throttle_end_time = allow_throttle_end_time
        # The start time of the throttling window. The value of this parameter is in UTC.
        self.allow_throttle_start_time = allow_throttle_start_time
        # Indicates whether abnormal SQL statements in execution are terminated at a time. Valid values:
        # 
        # > Abnormal SQL statements use the same template as the SQL statements that need to be throttled.
        # 
        # * **true**
        # * **false**
        self.auto_kill_session = auto_kill_session
        # The logical relationship between the CPU utilization threshold and the maximum number of active sessions. Valid values:
        # 
        # * **AND**
        # * **OR**
        self.cpu_session_relation = cpu_session_relation
        # The CPU utilization threshold.
        self.cpu_usage = cpu_usage
        # The database instance ID.
        self.instance_id = instance_id
        # The maximum throttling duration. Unit: minutes.
        self.max_throttle_time = max_throttle_time
        # The ID of the Alibaba Cloud account that is used to create the database instance.
        self.user_id = user_id
        # Indicates whether the automatic SQL throttling feature is enabled. Valid values:
        # 
        # * **true**
        # * **false**
        self.visible = visible

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.abnormal_duration is not None:
            result['AbnormalDuration'] = self.abnormal_duration

        if self.active_sessions is not None:
            result['ActiveSessions'] = self.active_sessions

        if self.allow_throttle_end_time is not None:
            result['AllowThrottleEndTime'] = self.allow_throttle_end_time

        if self.allow_throttle_start_time is not None:
            result['AllowThrottleStartTime'] = self.allow_throttle_start_time

        if self.auto_kill_session is not None:
            result['AutoKillSession'] = self.auto_kill_session

        if self.cpu_session_relation is not None:
            result['CpuSessionRelation'] = self.cpu_session_relation

        if self.cpu_usage is not None:
            result['CpuUsage'] = self.cpu_usage

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.max_throttle_time is not None:
            result['MaxThrottleTime'] = self.max_throttle_time

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.visible is not None:
            result['Visible'] = self.visible

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AbnormalDuration') is not None:
            self.abnormal_duration = m.get('AbnormalDuration')

        if m.get('ActiveSessions') is not None:
            self.active_sessions = m.get('ActiveSessions')

        if m.get('AllowThrottleEndTime') is not None:
            self.allow_throttle_end_time = m.get('AllowThrottleEndTime')

        if m.get('AllowThrottleStartTime') is not None:
            self.allow_throttle_start_time = m.get('AllowThrottleStartTime')

        if m.get('AutoKillSession') is not None:
            self.auto_kill_session = m.get('AutoKillSession')

        if m.get('CpuSessionRelation') is not None:
            self.cpu_session_relation = m.get('CpuSessionRelation')

        if m.get('CpuUsage') is not None:
            self.cpu_usage = m.get('CpuUsage')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('MaxThrottleTime') is not None:
            self.max_throttle_time = m.get('MaxThrottleTime')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('Visible') is not None:
            self.visible = m.get('Visible')

        return self

class GetAutoThrottleRulesResponseBodyDataEnableAutoThrottleList(DaraModel):
    def __init__(
        self,
        abnormal_duration: float = None,
        active_sessions: int = None,
        allow_throttle_end_time: str = None,
        allow_throttle_start_time: str = None,
        auto_kill_session: bool = None,
        cpu_session_relation: str = None,
        cpu_usage: float = None,
        instance_id: str = None,
        max_throttle_time: float = None,
        user_id: str = None,
        visible: bool = None,
    ):
        # The maximum period of time during which an exception occurs when automatic SQL throttling is triggered. Unit: minutes.
        self.abnormal_duration = abnormal_duration
        # The maximum number of active sessions.
        self.active_sessions = active_sessions
        # The end time of the throttling window. The value of this parameter is in UTC.
        self.allow_throttle_end_time = allow_throttle_end_time
        # The start time of the throttling window. The value of this parameter is in UTC.
        self.allow_throttle_start_time = allow_throttle_start_time
        # Indicates whether abnormal SQL statements in execution are terminated at a time. Valid values:
        # 
        # > Abnormal SQL statements use the same template as the SQL statements that need to be throttled.
        # 
        # * **true**
        # * **false**
        self.auto_kill_session = auto_kill_session
        # The logical relationship between the CPU utilization threshold and the maximum number of active sessions. Valid values:
        # 
        # * **AND**
        # * **OR**
        self.cpu_session_relation = cpu_session_relation
        # The CPU utilization threshold.
        self.cpu_usage = cpu_usage
        # The database instance ID.
        self.instance_id = instance_id
        # The maximum throttling duration. Unit: minutes.
        self.max_throttle_time = max_throttle_time
        # The ID of the Alibaba Cloud account that is used to create the database instance.
        self.user_id = user_id
        # Indicates whether the automatic SQL throttling feature is enabled. Valid values:
        # 
        # * **true**
        # * **false**
        self.visible = visible

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.abnormal_duration is not None:
            result['AbnormalDuration'] = self.abnormal_duration

        if self.active_sessions is not None:
            result['ActiveSessions'] = self.active_sessions

        if self.allow_throttle_end_time is not None:
            result['AllowThrottleEndTime'] = self.allow_throttle_end_time

        if self.allow_throttle_start_time is not None:
            result['AllowThrottleStartTime'] = self.allow_throttle_start_time

        if self.auto_kill_session is not None:
            result['AutoKillSession'] = self.auto_kill_session

        if self.cpu_session_relation is not None:
            result['CpuSessionRelation'] = self.cpu_session_relation

        if self.cpu_usage is not None:
            result['CpuUsage'] = self.cpu_usage

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.max_throttle_time is not None:
            result['MaxThrottleTime'] = self.max_throttle_time

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.visible is not None:
            result['Visible'] = self.visible

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AbnormalDuration') is not None:
            self.abnormal_duration = m.get('AbnormalDuration')

        if m.get('ActiveSessions') is not None:
            self.active_sessions = m.get('ActiveSessions')

        if m.get('AllowThrottleEndTime') is not None:
            self.allow_throttle_end_time = m.get('AllowThrottleEndTime')

        if m.get('AllowThrottleStartTime') is not None:
            self.allow_throttle_start_time = m.get('AllowThrottleStartTime')

        if m.get('AutoKillSession') is not None:
            self.auto_kill_session = m.get('AutoKillSession')

        if m.get('CpuSessionRelation') is not None:
            self.cpu_session_relation = m.get('CpuSessionRelation')

        if m.get('CpuUsage') is not None:
            self.cpu_usage = m.get('CpuUsage')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('MaxThrottleTime') is not None:
            self.max_throttle_time = m.get('MaxThrottleTime')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('Visible') is not None:
            self.visible = m.get('Visible')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSlowLogHistogramAsyncResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSlowLogHistogramAsyncResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        self.code = code
        # AsyncResult<Histogram>。
        self.data = data
        self.message = message
        self.request_id = request_id
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSlowLogHistogramAsyncResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSlowLogHistogramAsyncResponseBodyData(DaraModel):
    def __init__(
        self,
        data: main_models.DescribeSlowLogHistogramAsyncResponseBodyDataData = None,
        error_code: int = None,
        is_finish: bool = None,
        message: str = None,
        request_key: str = None,
        result_id: str = None,
        state: str = None,
        timestamp: int = None,
    ):
        self.data = data
        self.error_code = error_code
        self.is_finish = is_finish
        self.message = message
        self.request_key = request_key
        self.result_id = result_id
        self.state = state
        self.timestamp = timestamp

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.error_code is not None:
            result['ErrorCode'] = self.error_code

        if self.is_finish is not None:
            result['IsFinish'] = self.is_finish

        if self.message is not None:
            result['Message'] = self.message

        if self.request_key is not None:
            result['RequestKey'] = self.request_key

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        if self.state is not None:
            result['State'] = self.state

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Data') is not None:
            temp_model = main_models.DescribeSlowLogHistogramAsyncResponseBodyDataData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('ErrorCode') is not None:
            self.error_code = m.get('ErrorCode')

        if m.get('IsFinish') is not None:
            self.is_finish = m.get('IsFinish')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestKey') is not None:
            self.request_key = m.get('RequestKey')

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        return self

class DescribeSlowLogHistogramAsyncResponseBodyDataData(DaraModel):
    def __init__(
        self,
        avg_cputime: List[float] = None,
        avg_doc_examined: List[float] = None,
        avg_frows: List[float] = None,
        avg_iowrites: List[float] = None,
        avg_keys_examined: List[float] = None,
        avg_last_rows_count_affected: List[float] = None,
        avg_lock_time: List[float] = None,
        avg_logical_ioreads: List[float] = None,
        avg_physical_ioreads: List[float] = None,
        avg_return_num: List[float] = None,
        avg_rows: List[float] = None,
        avg_rows_count_affected: List[float] = None,
        avg_rows_examined: List[float] = None,
        avg_rows_sent: List[float] = None,
        avg_rt: List[float] = None,
        avg_scnt: List[float] = None,
        cputime: List[float] = None,
        count: List[int] = None,
        doc_examined: List[int] = None,
        frows: List[int] = None,
        iowrites: List[int] = None,
        item: List[main_models.DescribeSlowLogHistogramAsyncResponseBodyDataDataItem] = None,
        keys_examined: List[int] = None,
        last_rows_count_affected: List[int] = None,
        lock_time: List[float] = None,
        logical_ioreads: List[int] = None,
        max_cputime: List[float] = None,
        max_doc_examined: List[int] = None,
        max_frows: List[int] = None,
        max_iowrites: List[int] = None,
        max_keys_examined: List[int] = None,
        max_last_rows_count_affected: List[int] = None,
        max_lock_time: List[float] = None,
        max_logical_ioreads: List[int] = None,
        max_physical_ioreads: List[int] = None,
        max_return_num: List[int] = None,
        max_rows: List[int] = None,
        max_rows_count_affected: List[int] = None,
        max_rows_examined: List[int] = None,
        max_rows_sent: List[int] = None,
        max_rt: List[float] = None,
        max_scnt: List[int] = None,
        physical_ioreads: List[int] = None,
        return_num: List[int] = None,
        rows: List[int] = None,
        rows_count_affected: List[int] = None,
        rows_examined: List[int] = None,
        rows_sent: List[int] = None,
        rt: List[float] = None,
        scnt: List[int] = None,
        total: int = None,
        total_count: int = None,
        ts: List[int] = None,
        ts_end: List[int] = None,
    ):
        self.avg_cputime = avg_cputime
        self.avg_doc_examined = avg_doc_examined
        self.avg_frows = avg_frows
        self.avg_iowrites = avg_iowrites
        self.avg_keys_examined = avg_keys_examined
        self.avg_last_rows_count_affected = avg_last_rows_count_affected
        self.avg_lock_time = avg_lock_time
        self.avg_logical_ioreads = avg_logical_ioreads
        self.avg_physical_ioreads = avg_physical_ioreads
        self.avg_return_num = avg_return_num
        self.avg_rows = avg_rows
        self.avg_rows_count_affected = avg_rows_count_affected
        self.avg_rows_examined = avg_rows_examined
        self.avg_rows_sent = avg_rows_sent
        self.avg_rt = avg_rt
        self.avg_scnt = avg_scnt
        self.cputime = cputime
        self.count = count
        self.doc_examined = doc_examined
        self.frows = frows
        self.iowrites = iowrites
        self.item = item
        self.keys_examined = keys_examined
        self.last_rows_count_affected = last_rows_count_affected
        self.lock_time = lock_time
        self.logical_ioreads = logical_ioreads
        self.max_cputime = max_cputime
        self.max_doc_examined = max_doc_examined
        self.max_frows = max_frows
        self.max_iowrites = max_iowrites
        self.max_keys_examined = max_keys_examined
        self.max_last_rows_count_affected = max_last_rows_count_affected
        self.max_lock_time = max_lock_time
        self.max_logical_ioreads = max_logical_ioreads
        self.max_physical_ioreads = max_physical_ioreads
        self.max_return_num = max_return_num
        self.max_rows = max_rows
        self.max_rows_count_affected = max_rows_count_affected
        self.max_rows_examined = max_rows_examined
        self.max_rows_sent = max_rows_sent
        self.max_rt = max_rt
        self.max_scnt = max_scnt
        self.physical_ioreads = physical_ioreads
        self.return_num = return_num
        self.rows = rows
        self.rows_count_affected = rows_count_affected
        self.rows_examined = rows_examined
        self.rows_sent = rows_sent
        self.rt = rt
        self.scnt = scnt
        self.total = total
        self.total_count = total_count
        self.ts = ts
        self.ts_end = ts_end

    def validate(self):
        if self.item:
            for v1 in self.item:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.avg_cputime is not None:
            result['AvgCPUTime'] = self.avg_cputime

        if self.avg_doc_examined is not None:
            result['AvgDocExamined'] = self.avg_doc_examined

        if self.avg_frows is not None:
            result['AvgFrows'] = self.avg_frows

        if self.avg_iowrites is not None:
            result['AvgIOWrites'] = self.avg_iowrites

        if self.avg_keys_examined is not None:
            result['AvgKeysExamined'] = self.avg_keys_examined

        if self.avg_last_rows_count_affected is not None:
            result['AvgLastRowsCountAffected'] = self.avg_last_rows_count_affected

        if self.avg_lock_time is not None:
            result['AvgLockTime'] = self.avg_lock_time

        if self.avg_logical_ioreads is not None:
            result['AvgLogicalIOReads'] = self.avg_logical_ioreads

        if self.avg_physical_ioreads is not None:
            result['AvgPhysicalIOReads'] = self.avg_physical_ioreads

        if self.avg_return_num is not None:
            result['AvgReturnNum'] = self.avg_return_num

        if self.avg_rows is not None:
            result['AvgRows'] = self.avg_rows

        if self.avg_rows_count_affected is not None:
            result['AvgRowsCountAffected'] = self.avg_rows_count_affected

        if self.avg_rows_examined is not None:
            result['AvgRowsExamined'] = self.avg_rows_examined

        if self.avg_rows_sent is not None:
            result['AvgRowsSent'] = self.avg_rows_sent

        if self.avg_rt is not None:
            result['AvgRt'] = self.avg_rt

        if self.avg_scnt is not None:
            result['AvgScnt'] = self.avg_scnt

        if self.cputime is not None:
            result['CPUTime'] = self.cputime

        if self.count is not None:
            result['Count'] = self.count

        if self.doc_examined is not None:
            result['DocExamined'] = self.doc_examined

        if self.frows is not None:
            result['Frows'] = self.frows

        if self.iowrites is not None:
            result['IOWrites'] = self.iowrites

        result['Item'] = []
        if self.item is not None:
            for k1 in self.item:
                result['Item'].append(k1.to_map() if k1 else None)

        if self.keys_examined is not None:
            result['KeysExamined'] = self.keys_examined

        if self.last_rows_count_affected is not None:
            result['LastRowsCountAffected'] = self.last_rows_count_affected

        if self.lock_time is not None:
            result['LockTime'] = self.lock_time

        if self.logical_ioreads is not None:
            result['LogicalIOReads'] = self.logical_ioreads

        if self.max_cputime is not None:
            result['MaxCPUTime'] = self.max_cputime

        if self.max_doc_examined is not None:
            result['MaxDocExamined'] = self.max_doc_examined

        if self.max_frows is not None:
            result['MaxFrows'] = self.max_frows

        if self.max_iowrites is not None:
            result['MaxIOWrites'] = self.max_iowrites

        if self.max_keys_examined is not None:
            result['MaxKeysExamined'] = self.max_keys_examined

        if self.max_last_rows_count_affected is not None:
            result['MaxLastRowsCountAffected'] = self.max_last_rows_count_affected

        if self.max_lock_time is not None:
            result['MaxLockTime'] = self.max_lock_time

        if self.max_logical_ioreads is not None:
            result['MaxLogicalIOReads'] = self.max_logical_ioreads

        if self.max_physical_ioreads is not None:
            result['MaxPhysicalIOReads'] = self.max_physical_ioreads

        if self.max_return_num is not None:
            result['MaxReturnNum'] = self.max_return_num

        if self.max_rows is not None:
            result['MaxRows'] = self.max_rows

        if self.max_rows_count_affected is not None:
            result['MaxRowsCountAffected'] = self.max_rows_count_affected

        if self.max_rows_examined is not None:
            result['MaxRowsExamined'] = self.max_rows_examined

        if self.max_rows_sent is not None:
            result['MaxRowsSent'] = self.max_rows_sent

        if self.max_rt is not None:
            result['MaxRt'] = self.max_rt

        if self.max_scnt is not None:
            result['MaxScnt'] = self.max_scnt

        if self.physical_ioreads is not None:
            result['PhysicalIOReads'] = self.physical_ioreads

        if self.return_num is not None:
            result['ReturnNum'] = self.return_num

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.rows_count_affected is not None:
            result['RowsCountAffected'] = self.rows_count_affected

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_sent is not None:
            result['RowsSent'] = self.rows_sent

        if self.rt is not None:
            result['Rt'] = self.rt

        if self.scnt is not None:
            result['Scnt'] = self.scnt

        if self.total is not None:
            result['Total'] = self.total

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        if self.ts is not None:
            result['Ts'] = self.ts

        if self.ts_end is not None:
            result['TsEnd'] = self.ts_end

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AvgCPUTime') is not None:
            self.avg_cputime = m.get('AvgCPUTime')

        if m.get('AvgDocExamined') is not None:
            self.avg_doc_examined = m.get('AvgDocExamined')

        if m.get('AvgFrows') is not None:
            self.avg_frows = m.get('AvgFrows')

        if m.get('AvgIOWrites') is not None:
            self.avg_iowrites = m.get('AvgIOWrites')

        if m.get('AvgKeysExamined') is not None:
            self.avg_keys_examined = m.get('AvgKeysExamined')

        if m.get('AvgLastRowsCountAffected') is not None:
            self.avg_last_rows_count_affected = m.get('AvgLastRowsCountAffected')

        if m.get('AvgLockTime') is not None:
            self.avg_lock_time = m.get('AvgLockTime')

        if m.get('AvgLogicalIOReads') is not None:
            self.avg_logical_ioreads = m.get('AvgLogicalIOReads')

        if m.get('AvgPhysicalIOReads') is not None:
            self.avg_physical_ioreads = m.get('AvgPhysicalIOReads')

        if m.get('AvgReturnNum') is not None:
            self.avg_return_num = m.get('AvgReturnNum')

        if m.get('AvgRows') is not None:
            self.avg_rows = m.get('AvgRows')

        if m.get('AvgRowsCountAffected') is not None:
            self.avg_rows_count_affected = m.get('AvgRowsCountAffected')

        if m.get('AvgRowsExamined') is not None:
            self.avg_rows_examined = m.get('AvgRowsExamined')

        if m.get('AvgRowsSent') is not None:
            self.avg_rows_sent = m.get('AvgRowsSent')

        if m.get('AvgRt') is not None:
            self.avg_rt = m.get('AvgRt')

        if m.get('AvgScnt') is not None:
            self.avg_scnt = m.get('AvgScnt')

        if m.get('CPUTime') is not None:
            self.cputime = m.get('CPUTime')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('DocExamined') is not None:
            self.doc_examined = m.get('DocExamined')

        if m.get('Frows') is not None:
            self.frows = m.get('Frows')

        if m.get('IOWrites') is not None:
            self.iowrites = m.get('IOWrites')

        self.item = []
        if m.get('Item') is not None:
            for k1 in m.get('Item'):
                temp_model = main_models.DescribeSlowLogHistogramAsyncResponseBodyDataDataItem()
                self.item.append(temp_model.from_map(k1))

        if m.get('KeysExamined') is not None:
            self.keys_examined = m.get('KeysExamined')

        if m.get('LastRowsCountAffected') is not None:
            self.last_rows_count_affected = m.get('LastRowsCountAffected')

        if m.get('LockTime') is not None:
            self.lock_time = m.get('LockTime')

        if m.get('LogicalIOReads') is not None:
            self.logical_ioreads = m.get('LogicalIOReads')

        if m.get('MaxCPUTime') is not None:
            self.max_cputime = m.get('MaxCPUTime')

        if m.get('MaxDocExamined') is not None:
            self.max_doc_examined = m.get('MaxDocExamined')

        if m.get('MaxFrows') is not None:
            self.max_frows = m.get('MaxFrows')

        if m.get('MaxIOWrites') is not None:
            self.max_iowrites = m.get('MaxIOWrites')

        if m.get('MaxKeysExamined') is not None:
            self.max_keys_examined = m.get('MaxKeysExamined')

        if m.get('MaxLastRowsCountAffected') is not None:
            self.max_last_rows_count_affected = m.get('MaxLastRowsCountAffected')

        if m.get('MaxLockTime') is not None:
            self.max_lock_time = m.get('MaxLockTime')

        if m.get('MaxLogicalIOReads') is not None:
            self.max_logical_ioreads = m.get('MaxLogicalIOReads')

        if m.get('MaxPhysicalIOReads') is not None:
            self.max_physical_ioreads = m.get('MaxPhysicalIOReads')

        if m.get('MaxReturnNum') is not None:
            self.max_return_num = m.get('MaxReturnNum')

        if m.get('MaxRows') is not None:
            self.max_rows = m.get('MaxRows')

        if m.get('MaxRowsCountAffected') is not None:
            self.max_rows_count_affected = m.get('MaxRowsCountAffected')

        if m.get('MaxRowsExamined') is not None:
            self.max_rows_examined = m.get('MaxRowsExamined')

        if m.get('MaxRowsSent') is not None:
            self.max_rows_sent = m.get('MaxRowsSent')

        if m.get('MaxRt') is not None:
            self.max_rt = m.get('MaxRt')

        if m.get('MaxScnt') is not None:
            self.max_scnt = m.get('MaxScnt')

        if m.get('PhysicalIOReads') is not None:
            self.physical_ioreads = m.get('PhysicalIOReads')

        if m.get('ReturnNum') is not None:
            self.return_num = m.get('ReturnNum')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('RowsCountAffected') is not None:
            self.rows_count_affected = m.get('RowsCountAffected')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsSent') is not None:
            self.rows_sent = m.get('RowsSent')

        if m.get('Rt') is not None:
            self.rt = m.get('Rt')

        if m.get('Scnt') is not None:
            self.scnt = m.get('Scnt')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        if m.get('Ts') is not None:
            self.ts = m.get('Ts')

        if m.get('TsEnd') is not None:
            self.ts_end = m.get('TsEnd')

        return self

class DescribeSlowLogHistogramAsyncResponseBodyDataDataItem(DaraModel):
    def __init__(
        self,
        count: List[int] = None,
        ins_items: List[main_models.DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems] = None,
        ins_role: str = None,
        node_id: str = None,
        total_count: int = None,
    ):
        self.count = count
        self.ins_items = ins_items
        self.ins_role = ins_role
        self.node_id = node_id
        self.total_count = total_count

    def validate(self):
        if self.ins_items:
            for v1 in self.ins_items:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['Count'] = self.count

        result['InsItems'] = []
        if self.ins_items is not None:
            for k1 in self.ins_items:
                result['InsItems'].append(k1.to_map() if k1 else None)

        if self.ins_role is not None:
            result['InsRole'] = self.ins_role

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Count') is not None:
            self.count = m.get('Count')

        self.ins_items = []
        if m.get('InsItems') is not None:
            for k1 in m.get('InsItems'):
                temp_model = main_models.DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems()
                self.ins_items.append(temp_model.from_map(k1))

        if m.get('InsRole') is not None:
            self.ins_role = m.get('InsRole')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self

class DescribeSlowLogHistogramAsyncResponseBodyDataDataItemInsItems(DaraModel):
    def __init__(
        self,
        count: List[int] = None,
        ins_id: str = None,
        ins_role: str = None,
        total_count: int = None,
    ):
        self.count = count
        self.ins_id = ins_id
        self.ins_role = ins_role
        self.total_count = total_count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.count is not None:
            result['Count'] = self.count

        if self.ins_id is not None:
            result['InsId'] = self.ins_id

        if self.ins_role is not None:
            result['InsRole'] = self.ins_role

        if self.total_count is not None:
            result['TotalCount'] = self.total_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('InsId') is not None:
            self.ins_id = m.get('InsId')

        if m.get('InsRole') is not None:
            self.ins_role = m.get('InsRole')

        if m.get('TotalCount') is not None:
            self.total_count = m.get('TotalCount')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetAutoIncrementUsageStatisticResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.GetAutoIncrementUsageStatisticResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request is successful, **Successful** is returned. Otherwise, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request is successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.GetAutoIncrementUsageStatisticResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetAutoIncrementUsageStatisticResponseBodyData(DaraModel):
    def __init__(
        self,
        auto_increment_usage_list: List[main_models.GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList] = None,
        error_info: str = None,
        finish: bool = None,
        task_status: str = None,
        timestamp: int = None,
    ):
        # The usage details of auto-increment IDs.
        self.auto_increment_usage_list = auto_increment_usage_list
        # The error message returned if the task fails.
        self.error_info = error_info
        # Indicates whether the task is complete. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.finish = finish
        # The task status. Valid values:
        # 
        # *   **INIT**: The task is being initialized.
        # *   **RUNNING**: The task is being executed.
        # *   **SUCCESS**: The task succeeds.
        # *   **FAIL**: The task fails.
        self.task_status = task_status
        # The time when the request was made. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp

    def validate(self):
        if self.auto_increment_usage_list:
            for v1 in self.auto_increment_usage_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['AutoIncrementUsageList'] = []
        if self.auto_increment_usage_list is not None:
            for k1 in self.auto_increment_usage_list:
                result['AutoIncrementUsageList'].append(k1.to_map() if k1 else None)

        if self.error_info is not None:
            result['ErrorInfo'] = self.error_info

        if self.finish is not None:
            result['Finish'] = self.finish

        if self.task_status is not None:
            result['TaskStatus'] = self.task_status

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.auto_increment_usage_list = []
        if m.get('AutoIncrementUsageList') is not None:
            for k1 in m.get('AutoIncrementUsageList'):
                temp_model = main_models.GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList()
                self.auto_increment_usage_list.append(temp_model.from_map(k1))

        if m.get('ErrorInfo') is not None:
            self.error_info = m.get('ErrorInfo')

        if m.get('Finish') is not None:
            self.finish = m.get('Finish')

        if m.get('TaskStatus') is not None:
            self.task_status = m.get('TaskStatus')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        return self

class GetAutoIncrementUsageStatisticResponseBodyDataAutoIncrementUsageList(DaraModel):
    def __init__(
        self,
        auto_increment_current_value: int = None,
        auto_increment_ratio: float = None,
        column_name: str = None,
        db_name: str = None,
        maximum_value: int = None,
        table_name: str = None,
    ):
        # The latest auto-increment ID.
        self.auto_increment_current_value = auto_increment_current_value
        # The usage ratio of auto-increment IDs.
        self.auto_increment_ratio = auto_increment_ratio
        # The column name.
        self.column_name = column_name
        # The database name.
        self.db_name = db_name
        # The maximum auto-increment ID that is supported by the current data type.
        self.maximum_value = maximum_value
        # The table name.
        self.table_name = table_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.auto_increment_current_value is not None:
            result['AutoIncrementCurrentValue'] = self.auto_increment_current_value

        if self.auto_increment_ratio is not None:
            result['AutoIncrementRatio'] = self.auto_increment_ratio

        if self.column_name is not None:
            result['ColumnName'] = self.column_name

        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.maximum_value is not None:
            result['MaximumValue'] = self.maximum_value

        if self.table_name is not None:
            result['TableName'] = self.table_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AutoIncrementCurrentValue') is not None:
            self.auto_increment_current_value = m.get('AutoIncrementCurrentValue')

        if m.get('AutoIncrementRatio') is not None:
            self.auto_increment_ratio = m.get('AutoIncrementRatio')

        if m.get('ColumnName') is not None:
            self.column_name = m.get('ColumnName')

        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('MaximumValue') is not None:
            self.maximum_value = m.get('MaximumValue')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateStorageAnalysisTaskRequest(DaraModel):
    def __init__(
        self,
        db_name: str = None,
        instance_id: str = None,
        node_id: str = None,
        table_name: str = None,
    ):
        # The database name. If you specify a database, the operation analyzes the storage usage of the specified database.
        self.db_name = db_name
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID. For ApsaraDB for MongoDB instances, you can use this parameter to specify a node for storage analysis. You can call the [DescribeRoleZoneInfo](https://help.aliyun.com/document_detail/123802.html) operation to query the information about nodes of an ApsaraDB for MongoDB instance.
        # 
        # *   If you set this parameter to a value in the **InsName** format, such as `d-bp1872fa24d5****`, you can call this operation to analyze the hidden node that corresponds to the node ID.
        # *   If you set this parameter to a value in the `InsName#RoleId` format, such as `d-bp1872fa24d5****#299****5`, you can call this operation to analyze the specified node.
        # 
        # >  If you run a storage analysis task on an ApsaraDB for MongoDB replica set instance and you do not specify this parameter, only the hidden node of the instance is analyzed by default. If you run a storage analysis task on an ApsaraDB for MongoDB sharded cluster instance, we recommend that you set this parameter to specify a node.
        self.node_id = node_id
        # The table name. If you specify a table in the specified database, the operation analyzes the storage usage of the specified table. If you specify a table, you must also specify the database to which the table belongs by using **DbName**.
        self.table_name = table_name

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.db_name is not None:
            result['DbName'] = self.db_name

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.table_name is not None:
            result['TableName'] = self.table_name

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('DbName') is not None:
            self.db_name = m.get('DbName')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class DataResultValue(DaraModel):
    def __init__(
        self,
        sql_id: str = None,
        instance_id: str = None,
        count: int = None,
    ):
        self.sql_id = sql_id
        self.instance_id = instance_id
        self.count = count

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.sql_id is not None:
            result['sqlId'] = self.sql_id

        if self.instance_id is not None:
            result['instanceId'] = self.instance_id

        if self.count is not None:
            result['count'] = self.count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('sqlId') is not None:
            self.sql_id = m.get('sqlId')

        if m.get('instanceId') is not None:
            self.instance_id = m.get('instanceId')

        if m.get('count') is not None:
            self.count = m.get('count')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class GetMongoDBCurrentOpRequest(DaraModel):
    def __init__(
        self,
        filter_doc: str = None,
        instance_id: str = None,
        node_id: str = None,
        role: str = None,
    ):
        # The `db.currentOp()` command that is used to filter sessions. For more information, see [db.currentOp()](https://docs.mongodb.com/manual/reference/method/db.currentOp/) of MongoDB Documentation.
        self.filter_doc = filter_doc
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The node ID.
        # 
        # >  If you do not specify a node ID, the sessions of the primary node are queried by default.
        self.node_id = node_id
        # A reserved parameter. You do not need to specify the parameter.
        self.role = role

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.filter_doc is not None:
            result['FilterDoc'] = self.filter_doc

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.role is not None:
            result['Role'] = self.role

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('FilterDoc') is not None:
            self.filter_doc = m.get('FilterDoc')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Role') is not None:
            self.role = m.get('Role')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class CreateStorageAnalysisTaskResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.CreateStorageAnalysisTaskResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request is successful, **Successful** is returned. Otherwise, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request is successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.CreateStorageAnalysisTaskResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class CreateStorageAnalysisTaskResponseBodyData(DaraModel):
    def __init__(
        self,
        create_task_success: bool = None,
        error_message: str = None,
        task_id: str = None,
    ):
        # Indicates whether the task is created. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.create_task_success = create_task_success
        # The error message returned.
        self.error_message = error_message
        # The task ID.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_task_success is not None:
            result['CreateTaskSuccess'] = self.create_task_success

        if self.error_message is not None:
            result['ErrorMessage'] = self.error_message

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTaskSuccess') is not None:
            self.create_task_success = m.get('CreateTaskSuccess')

        if m.get('ErrorMessage') is not None:
            self.error_message = m.get('ErrorMessage')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class ModifyAutoScalingConfigRequest(DaraModel):
    def __init__(
        self,
        bandwidth: main_models.ModifyAutoScalingConfigRequestBandwidth = None,
        instance_id: str = None,
        resource: main_models.ModifyAutoScalingConfigRequestResource = None,
        shard: main_models.ModifyAutoScalingConfigRequestShard = None,
        spec: main_models.ModifyAutoScalingConfigRequestSpec = None,
        storage: main_models.ModifyAutoScalingConfigRequestStorage = None,
    ):
        # The configuration item of the bandwidth auto scaling feature.
        self.bandwidth = bandwidth
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The configuration item of the resource auto scaling feature.
        self.resource = resource
        # The configuration item of the shard auto scaling feature.
        self.shard = shard
        # The configuration item of the specification auto scaling feature.
        self.spec = spec
        # The configuration item of the automatic storage expansion feature.
        self.storage = storage

    def validate(self):
        if self.bandwidth:
            self.bandwidth.validate()
        if self.resource:
            self.resource.validate()
        if self.shard:
            self.shard.validate()
        if self.spec:
            self.spec.validate()
        if self.storage:
            self.storage.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bandwidth is not None:
            result['Bandwidth'] = self.bandwidth.to_map()

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.resource is not None:
            result['Resource'] = self.resource.to_map()

        if self.shard is not None:
            result['Shard'] = self.shard.to_map()

        if self.spec is not None:
            result['Spec'] = self.spec.to_map()

        if self.storage is not None:
            result['Storage'] = self.storage.to_map()

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bandwidth') is not None:
            temp_model = main_models.ModifyAutoScalingConfigRequestBandwidth()
            self.bandwidth = temp_model.from_map(m.get('Bandwidth'))

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Resource') is not None:
            temp_model = main_models.ModifyAutoScalingConfigRequestResource()
            self.resource = temp_model.from_map(m.get('Resource'))

        if m.get('Shard') is not None:
            temp_model = main_models.ModifyAutoScalingConfigRequestShard()
            self.shard = temp_model.from_map(m.get('Shard'))

        if m.get('Spec') is not None:
            temp_model = main_models.ModifyAutoScalingConfigRequestSpec()
            self.spec = temp_model.from_map(m.get('Spec'))

        if m.get('Storage') is not None:
            temp_model = main_models.ModifyAutoScalingConfigRequestStorage()
            self.storage = temp_model.from_map(m.get('Storage'))

        return self

class ModifyAutoScalingConfigRequestStorage(DaraModel):
    def __init__(
        self,
        apply: bool = None,
        disk_usage_upper_threshold: int = None,
        max_storage: int = None,
        upgrade: bool = None,
    ):
        # Specifies whether to apply the **Storage** configuration of the automatic storage expansion feature. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.apply = apply
        # The average storage usage threshold that triggers automatic storage expansion. Unit: %. Valid values:
        # 
        # *   **50**
        # *   **60**
        # *   **70**
        # *   **80**
        # *   **90**
        self.disk_usage_upper_threshold = disk_usage_upper_threshold
        # The maximum storage size of the database instance. Unit: GB. The value must be greater than or equal to the total storage size of the instance.
        # 
        # *   If the instance uses ESSDs, the maximum value of this parameter can be 32000.
        # *   If the instance uses standard SSDs, the maximum value of this parameter can be 6000.
        # 
        # >  The standard SSD storage type is phased out. We recommend that you [upgrade the storage type of your instance from standard SSDs to ESSDs](https://help.aliyun.com/document_detail/314678.html).
        self.max_storage = max_storage
        # Specifies whether to enable automatic storage expansion. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.upgrade = upgrade

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.apply is not None:
            result['Apply'] = self.apply

        if self.disk_usage_upper_threshold is not None:
            result['DiskUsageUpperThreshold'] = self.disk_usage_upper_threshold

        if self.max_storage is not None:
            result['MaxStorage'] = self.max_storage

        if self.upgrade is not None:
            result['Upgrade'] = self.upgrade

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Apply') is not None:
            self.apply = m.get('Apply')

        if m.get('DiskUsageUpperThreshold') is not None:
            self.disk_usage_upper_threshold = m.get('DiskUsageUpperThreshold')

        if m.get('MaxStorage') is not None:
            self.max_storage = m.get('MaxStorage')

        if m.get('Upgrade') is not None:
            self.upgrade = m.get('Upgrade')

        return self

class ModifyAutoScalingConfigRequestSpec(DaraModel):
    def __init__(
        self,
        apply: bool = None,
        cool_down_time: str = None,
        cpu_usage_upper_threshold: int = None,
        downgrade: bool = None,
        max_read_only_nodes: int = None,
        max_spec: str = None,
        mem_usage_upper_threshold: int = None,
        observation_window_size: str = None,
        upgrade: bool = None,
    ):
        # Specifies whether to apply the **Spec** configuration of the specification auto scaling feature. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.apply = apply
        # The quiescent period. The value of this parameter consists of a numeric value and a time unit suffix. The **m** time unit suffix specifies the minute, the **h** time unit suffix specifies the hour, and the **d** time unit suffix specifies the day.
        # 
        # *   Valid values for PolarDB for MySQL Cluster Edition instances: **5m**, **10m**, **30m**, **1h**, **2h**, **3h**, **1d**, and **7d**.
        # *   Valid values for ApsaraDB RDS for MySQL High-availability Edition instances that use standard SSDs or Enterprise SSDs (ESSDs): **5m**, **10m**, **30m**, **1h**, **2h**, **3h**, **1d**, and **7d**.
        self.cool_down_time = cool_down_time
        # The average CPU utilization threshold that triggers automatic specification scale-up. Unit: %. Valid values:
        # 
        # *   **50**
        # *   **60**
        # *   **70**
        # *   **80**
        # *   **90**
        # 
        # >  This parameter must be specified if the database instance is a PolarDB for MySQL Cluster Edition instance or an ApsaraDB RDS for MySQL High-availability Edition instance that uses standard SSDs or ESSDs.
        self.cpu_usage_upper_threshold = cpu_usage_upper_threshold
        # Specifies whether to enable automatic specification scale-down. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  This parameter must be specified if the database instance is a PolarDB for MySQL Cluster Edition instance or an ApsaraDB RDS for MySQL High-availability Edition instance that uses standard SSDs or ESSDs.
        self.downgrade = downgrade
        # The maximum number of read-only nodes of the instance.
        # 
        # >  This parameter must be specified if the database instance is a PolarDB for MySQL Cluster Edition instance.
        self.max_read_only_nodes = max_read_only_nodes
        # The maximum specifications to which the database instance can be scaled up. The database instance can be upgraded only to a database instance of the same edition with higher specifications. For information about the specifications of different database instances, see the following topics:
        # 
        # *   PolarDB for MySQL Cluster Edition instances: [Specifications of compute nodes](https://help.aliyun.com/document_detail/102542.html)
        # *   ApsaraDB RDS for MySQL High-availability Edition instances that use standard SSDs or ESSDs: [Specifications](https://help.aliyun.com/document_detail/276974.html)
        self.max_spec = max_spec
        # The average memory usage threshold that triggers automatic specification scale-up. Unit: %. Valid values:
        # 
        # *   **50**
        # *   **60**
        # *   **70**
        # *   **80**
        # *   **90**
        # 
        # >  This parameter must be specified if the database instance is a Tair (Redis OSS-compatible) Community Edition cloud-native instance on the China site (aliyun.com).
        self.mem_usage_upper_threshold = mem_usage_upper_threshold
        # The observation window. The value of this parameter consists of a numeric value and a time unit suffix. The **m** time unit suffix specifies the minute and the **h** time unit suffix specifies the hour.
        # 
        # *   Valid values for PolarDB for MySQL Cluster Edition instances: **5m**, **10m**, **15m**, and **30m**.
        # *   Valid values for ApsaraDB RDS for MySQL High-availability Edition instances that use standard SSDs or ESSDs: **5m**, **20m**, **30m**, **40m**, and **1h**.
        # *   Valid values for Tair (Redis OSS-compatible) Community Edition cloud-native instances: **5m**, **10m**, **15m**, and **30m**.
        self.observation_window_size = observation_window_size
        # Specifies whether to enable automatic specification scale-up. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.upgrade = upgrade

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.apply is not None:
            result['Apply'] = self.apply

        if self.cool_down_time is not None:
            result['CoolDownTime'] = self.cool_down_time

        if self.cpu_usage_upper_threshold is not None:
            result['CpuUsageUpperThreshold'] = self.cpu_usage_upper_threshold

        if self.downgrade is not None:
            result['Downgrade'] = self.downgrade

        if self.max_read_only_nodes is not None:
            result['MaxReadOnlyNodes'] = self.max_read_only_nodes

        if self.max_spec is not None:
            result['MaxSpec'] = self.max_spec

        if self.mem_usage_upper_threshold is not None:
            result['MemUsageUpperThreshold'] = self.mem_usage_upper_threshold

        if self.observation_window_size is not None:
            result['ObservationWindowSize'] = self.observation_window_size

        if self.upgrade is not None:
            result['Upgrade'] = self.upgrade

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Apply') is not None:
            self.apply = m.get('Apply')

        if m.get('CoolDownTime') is not None:
            self.cool_down_time = m.get('CoolDownTime')

        if m.get('CpuUsageUpperThreshold') is not None:
            self.cpu_usage_upper_threshold = m.get('CpuUsageUpperThreshold')

        if m.get('Downgrade') is not None:
            self.downgrade = m.get('Downgrade')

        if m.get('MaxReadOnlyNodes') is not None:
            self.max_read_only_nodes = m.get('MaxReadOnlyNodes')

        if m.get('MaxSpec') is not None:
            self.max_spec = m.get('MaxSpec')

        if m.get('MemUsageUpperThreshold') is not None:
            self.mem_usage_upper_threshold = m.get('MemUsageUpperThreshold')

        if m.get('ObservationWindowSize') is not None:
            self.observation_window_size = m.get('ObservationWindowSize')

        if m.get('Upgrade') is not None:
            self.upgrade = m.get('Upgrade')

        return self

class ModifyAutoScalingConfigRequestShard(DaraModel):
    def __init__(
        self,
        apply: bool = None,
        downgrade: bool = None,
        downgrade_observation_window_size: str = None,
        max_shards: int = None,
        mem_usage_lower_threshold: int = None,
        mem_usage_upper_threshold: int = None,
        min_shards: int = None,
        upgrade: bool = None,
        upgrade_observation_window_size: str = None,
    ):
        # Specifies whether to apply the **Shard** configuration of the shard auto scaling feature. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  The shard auto scaling feature is available only for Tair (Redis OSS-compatible) cloud-native cluster instances on the China site (aliyun.com).
        self.apply = apply
        # Specifies whether to enable automatic shard removal. Valid values:
        # 
        # *   **true**
        # *   **false**
        # 
        # >  The automatic shard removal feature is in a canary release.
        self.downgrade = downgrade
        # The observation window of the automatic shard removal feature. The value of this parameter consists of a numeric value and a time unit suffix. The **h** time unit suffix specifies the hour. The **d** time unit suffix specifies the day. Valid values:
        # 
        # *   **1h**
        # *   **2h**
        # *   **3h**
        # *   **1d**
        # *   **7d**
        self.downgrade_observation_window_size = downgrade_observation_window_size
        # The maximum number of shards in the instance. The value must be a positive integer. Valid values: 4 to 32.
        self.max_shards = max_shards
        # The average memory usage threshold that triggers automatic shard removal. Unit: %. Valid values:
        # 
        # *   **10**
        # *   **20**
        # *   **30**
        self.mem_usage_lower_threshold = mem_usage_lower_threshold
        # The average memory usage threshold that triggers automatic shard addition. Unit: %. Valid values:
        # 
        # *   **50**
        # *   **60**
        # *   **70**
        # *   **80**
        # *   **90**
        self.mem_usage_upper_threshold = mem_usage_upper_threshold
        # The minimum number of shards in the instance. The value must be a positive integer. Valid values: 4 to 32.
        self.min_shards = min_shards
        # Specifies whether to enable automatic shard addition. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.upgrade = upgrade
        # The observation window of the automatic shard addition feature. The value of this parameter consists of a numeric value and a time unit suffix. The **m** time unit suffix specifies the minute. Valid values:
        # 
        # *   **5m**
        # *   **10m**
        # *   **15m**
        # *   **30m**
        self.upgrade_observation_window_size = upgrade_observation_window_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.apply is not None:
            result['Apply'] = self.apply

        if self.downgrade is not None:
            result['Downgrade'] = self.downgrade

        if self.downgrade_observation_window_size is not None:
            result['DowngradeObservationWindowSize'] = self.downgrade_observation_window_size

        if self.max_shards is not None:
            result['MaxShards'] = self.max_shards

        if self.mem_usage_lower_threshold is not None:
            result['MemUsageLowerThreshold'] = self.mem_usage_lower_threshold

        if self.mem_usage_upper_threshold is not None:
            result['MemUsageUpperThreshold'] = self.mem_usage_upper_threshold

        if self.min_shards is not None:
            result['MinShards'] = self.min_shards

        if self.upgrade is not None:
            result['Upgrade'] = self.upgrade

        if self.upgrade_observation_window_size is not None:
            result['UpgradeObservationWindowSize'] = self.upgrade_observation_window_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Apply') is not None:
            self.apply = m.get('Apply')

        if m.get('Downgrade') is not None:
            self.downgrade = m.get('Downgrade')

        if m.get('DowngradeObservationWindowSize') is not None:
            self.downgrade_observation_window_size = m.get('DowngradeObservationWindowSize')

        if m.get('MaxShards') is not None:
            self.max_shards = m.get('MaxShards')

        if m.get('MemUsageLowerThreshold') is not None:
            self.mem_usage_lower_threshold = m.get('MemUsageLowerThreshold')

        if m.get('MemUsageUpperThreshold') is not None:
            self.mem_usage_upper_threshold = m.get('MemUsageUpperThreshold')

        if m.get('MinShards') is not None:
            self.min_shards = m.get('MinShards')

        if m.get('Upgrade') is not None:
            self.upgrade = m.get('Upgrade')

        if m.get('UpgradeObservationWindowSize') is not None:
            self.upgrade_observation_window_size = m.get('UpgradeObservationWindowSize')

        return self

class ModifyAutoScalingConfigRequestResource(DaraModel):
    def __init__(
        self,
        apply: bool = None,
        cpu_usage_upper_threshold: int = None,
        downgrade_observation_window_size: str = None,
        enable: bool = None,
        upgrade_observation_window_size: str = None,
    ):
        # Specifies whether to apply the **Resource** configuration of the resource auto scaling feature. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.apply = apply
        # The average CPU utilization threshold that triggers automatic resource scale-out. Unit: %. Valid values:
        # 
        # *   **70**
        # *   **80**
        # *   **90**
        self.cpu_usage_upper_threshold = cpu_usage_upper_threshold
        # The observation window of the automatic resource scale-in feature. The value of this parameter consists of a numeric value and a time unit suffix. The **m** time unit suffix specifies the minute. Valid values:
        # 
        # *   **1m**
        # *   **3m**
        # *   **5m**
        # *   **10m**
        # *   **20m**
        # *   **30m**
        self.downgrade_observation_window_size = downgrade_observation_window_size
        # Specifies whether to enable resource auto scaling. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.enable = enable
        # The observation window of the automatic resource scale-out feature. The value of this parameter consists of a numeric value and a time unit suffix. The **m** time unit suffix specifies the minute. Valid values:
        # 
        # *   **1m**
        # *   **3m**
        # *   **5m**
        # *   **10m**
        # *   **20m**
        # *   **30m**
        self.upgrade_observation_window_size = upgrade_observation_window_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.apply is not None:
            result['Apply'] = self.apply

        if self.cpu_usage_upper_threshold is not None:
            result['CpuUsageUpperThreshold'] = self.cpu_usage_upper_threshold

        if self.downgrade_observation_window_size is not None:
            result['DowngradeObservationWindowSize'] = self.downgrade_observation_window_size

        if self.enable is not None:
            result['Enable'] = self.enable

        if self.upgrade_observation_window_size is not None:
            result['UpgradeObservationWindowSize'] = self.upgrade_observation_window_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Apply') is not None:
            self.apply = m.get('Apply')

        if m.get('CpuUsageUpperThreshold') is not None:
            self.cpu_usage_upper_threshold = m.get('CpuUsageUpperThreshold')

        if m.get('DowngradeObservationWindowSize') is not None:
            self.downgrade_observation_window_size = m.get('DowngradeObservationWindowSize')

        if m.get('Enable') is not None:
            self.enable = m.get('Enable')

        if m.get('UpgradeObservationWindowSize') is not None:
            self.upgrade_observation_window_size = m.get('UpgradeObservationWindowSize')

        return self

class ModifyAutoScalingConfigRequestBandwidth(DaraModel):
    def __init__(
        self,
        apply: bool = None,
        bandwidth_usage_lower_threshold: int = None,
        bandwidth_usage_upper_threshold: int = None,
        downgrade: bool = None,
        observation_window_size: str = None,
        upgrade: bool = None,
    ):
        # Specifies whether to apply the **Bandwidth** configuration of the bandwidth auto scaling feature. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.apply = apply
        # The average bandwidth usage threshold that triggers automatic bandwidth downgrade. Unit: %. Valid values:
        # 
        # *   **10**
        # *   **20**
        # *   **30**
        self.bandwidth_usage_lower_threshold = bandwidth_usage_lower_threshold
        # The average bandwidth usage threshold that triggers automatic bandwidth upgrade. Unit: %. Valid values:
        # 
        # *   **50**
        # *   **60**
        # *   **70**
        # *   **80**
        # *   **90**
        # *   **95**
        self.bandwidth_usage_upper_threshold = bandwidth_usage_upper_threshold
        # Specifies whether to enable automatic bandwidth downgrade. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.downgrade = downgrade
        # The observation window of the bandwidth auto scaling feature. The value of this parameter consists of a numeric value and a time unit suffix. The **m** time unit suffix specifies the minute. Valid values:
        # 
        # *   **1m**
        # *   **5m**
        # *   **10m**
        # *   **15m**
        # *   **30m**
        self.observation_window_size = observation_window_size
        # Specifies whether to enable automatic bandwidth upgrade. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.upgrade = upgrade

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.apply is not None:
            result['Apply'] = self.apply

        if self.bandwidth_usage_lower_threshold is not None:
            result['BandwidthUsageLowerThreshold'] = self.bandwidth_usage_lower_threshold

        if self.bandwidth_usage_upper_threshold is not None:
            result['BandwidthUsageUpperThreshold'] = self.bandwidth_usage_upper_threshold

        if self.downgrade is not None:
            result['Downgrade'] = self.downgrade

        if self.observation_window_size is not None:
            result['ObservationWindowSize'] = self.observation_window_size

        if self.upgrade is not None:
            result['Upgrade'] = self.upgrade

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Apply') is not None:
            self.apply = m.get('Apply')

        if m.get('BandwidthUsageLowerThreshold') is not None:
            self.bandwidth_usage_lower_threshold = m.get('BandwidthUsageLowerThreshold')

        if m.get('BandwidthUsageUpperThreshold') is not None:
            self.bandwidth_usage_upper_threshold = m.get('BandwidthUsageUpperThreshold')

        if m.get('Downgrade') is not None:
            self.downgrade = m.get('Downgrade')

        if m.get('ObservationWindowSize') is not None:
            self.observation_window_size = m.get('ObservationWindowSize')

        if m.get('Upgrade') is not None:
            self.upgrade = m.get('Upgrade')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateKillInstanceSessionTaskWithMaintainUserRequest(DaraModel):
    def __init__(
        self,
        ignored_users: str = None,
        instance_id: str = None,
        kill_all_sessions: bool = None,
        node_id: str = None,
        session_ids: str = None,
    ):
        self.ignored_users = ignored_users
        # This parameter is required.
        self.instance_id = instance_id
        # This parameter is required.
        self.kill_all_sessions = kill_all_sessions
        self.node_id = node_id
        self.session_ids = session_ids

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.ignored_users is not None:
            result['IgnoredUsers'] = self.ignored_users

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.kill_all_sessions is not None:
            result['KillAllSessions'] = self.kill_all_sessions

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.session_ids is not None:
            result['SessionIds'] = self.session_ids

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('IgnoredUsers') is not None:
            self.ignored_users = m.get('IgnoredUsers')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('KillAllSessions') is not None:
            self.kill_all_sessions = m.get('KillAllSessions')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('SessionIds') is not None:
            self.session_ids = m.get('SessionIds')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class UpdateAutoResourceOptimizeRulesAsyncRequest(DaraModel):
    def __init__(
        self,
        console_context: str = None,
        instance_ids: str = None,
        result_id: str = None,
        table_fragmentation_ratio: float = None,
        table_space_size: float = None,
    ):
        # The reserved parameter.
        self.console_context = console_context
        # The database instance IDs.
        # 
        # >  Set this parameter to a JSON array that consists of multiple instance IDs. Separate instance IDs with commas (,). Example: `[\\"Instance ID1\\", \\"Instance ID2\\"]`.
        # 
        # This parameter is required.
        self.instance_ids = instance_ids
        # The ID of the asynchronous request.
        # 
        # >  Asynchronous calls do not immediately return the complete results. To obtain the complete results, you must use the value of **ResultId** returned in the response to re-initiate the call until the value of **isFinish** is **true**.**** In this case, you must call this operation at least twice.
        self.result_id = result_id
        # The fragmentation rate that triggers automatic fragment recycling of a single physical table. Valid values: **0.10** to **0.99**.
        # 
        # This parameter is required.
        self.table_fragmentation_ratio = table_fragmentation_ratio
        # The minimum storage usage that triggers automatic fragment recycling of a single physical table. Valid values: **5** to **100**. Unit: GB.
        # 
        # This parameter is required.
        self.table_space_size = table_space_size

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.console_context is not None:
            result['ConsoleContext'] = self.console_context

        if self.instance_ids is not None:
            result['InstanceIds'] = self.instance_ids

        if self.result_id is not None:
            result['ResultId'] = self.result_id

        if self.table_fragmentation_ratio is not None:
            result['TableFragmentationRatio'] = self.table_fragmentation_ratio

        if self.table_space_size is not None:
            result['TableSpaceSize'] = self.table_space_size

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConsoleContext') is not None:
            self.console_context = m.get('ConsoleContext')

        if m.get('InstanceIds') is not None:
            self.instance_ids = m.get('InstanceIds')

        if m.get('ResultId') is not None:
            self.result_id = m.get('ResultId')

        if m.get('TableFragmentationRatio') is not None:
            self.table_fragmentation_ratio = m.get('TableFragmentationRatio')

        if m.get('TableSpaceSize') is not None:
            self.table_space_size = m.get('TableSpaceSize')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class SetEventSubscriptionRequest(DaraModel):
    def __init__(
        self,
        active: str = None,
        channel_type: str = None,
        contact_group_name: str = None,
        contact_name: str = None,
        dispatch_rule: str = None,
        event_context: str = None,
        instance_id: str = None,
        lang: str = None,
        level: str = None,
        min_interval: str = None,
        severity: str = None,
    ):
        # Specifies whether to enable the event subscription feature. Valid values:
        # 
        # *   **0**: disables the event subscription feature.
        # *   **1**: enables the event subscription feature.
        self.active = active
        # The notification method. Valid values:
        # 
        # *   **hdm_alarm_sms**: text message.
        # *   **dingtalk**: DingTalk chatbot.
        # *   **hdm_alarm_sms_and_email**: text message and email.
        # *   **hdm_alarm_sms,dingtalk**: text message and DingTalk chatbot.
        self.channel_type = channel_type
        # The name of the contact group that receives alert notifications. Separate multiple names with commas (,).
        self.contact_group_name = contact_group_name
        # The name of the contact who receives alert notifications. Separate multiple names with commas (,).
        self.contact_name = contact_name
        # The notification rules based on the event type. If you leave this parameter empty, the values of **MinInterval** and **ChannelType** prevail.
        # 
        # Specify this parameter in the following format: `{"silenced": {"Event type 1":Specifies whether to enable adaptive silence, "Event type 2":Specify whether to enable adaptive silence},"min_interval": {"Event type 1":Minimum interval between event notifications, "Event type 2":Minimum interval between event notifications},"alert_type": {"Event type 1":"Notification method", "Event type 2":"Notification method"}}`.
        # 
        # *   **silenced**: specifies whether to enable adaptive silence. After you enable adaptive silence, the interval between consecutive alert notifications for an event is the greater one of the minimum interval specified by **min_interval** and one third of the event duration. Valid values:
        # 
        #     *   1: enables adaptive silence.
        #     *   2: disables adaptive silence.
        # 
        # *   **min_interval**: the minimum interval between event notifications. Unit: seconds.
        # 
        # *   **alert_type**: the notification method. Valid values:
        # 
        #     *   **hdm_alarm_sms**: text message.
        #     *   **dingtalk**: DingTalk chatbot.
        #     *   **hdm_alarm_sms_and_email**: text message and email.
        #     *   **hdm_alarm_sms,dingtalk**: text message and DingTalk chatbot.
        self.dispatch_rule = dispatch_rule
        # The supported event scenarios. You can set the value to **AllContext**, which indicates that all scenarios are supported.
        self.event_context = event_context
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The language of event notifications. You can set the value to **zh-CN**, which indicates that event notifications are sent in Chinese.
        self.lang = lang
        # The risk level of the events. Valid values:
        # 
        # *   **Notice**: events that trigger notifications, including events at the **Notice**, **Optimization**, **Warn**, and **Critical** levels.
        # *   **Optimization**: events that trigger optimizations, including events at the **Optimization**, **Warn**, and **Critical** levels.
        # *   **Warn**: events that trigger warnings, including events at the **Warn** and **Critical** levels.
        # *   **Critical**: events that trigger critical warnings.
        # 
        # The following content describes the events at each level in detail:
        # 
        # *   Notice: events that are related to database exceptions for which no suggestions are generated.
        # *   Optimization: events for which optimization suggestions are generated based on the status of the database.
        # *   Warn: events that may affect the running of the database.
        # *   Critical: events that affect the running of the database.
        self.level = level
        # The minimum interval between consecutive event notifications. Unit: seconds.
        self.min_interval = min_interval
        # The alert severity based on the event type.
        # 
        # Specify this parameter in the following format: `{"Event type 1":"Alert severity", "Event type 2":"Alert severity"}`.
        # 
        # Valid values of event types:
        # 
        # *   **AutoScale**: auto scaling event.
        # *   **SQLThrottle**: throttling event.
        # *   **TimeSeriesAbnormal**: event for detecting time series anomalies.
        # *   **SQLOptimize**: SQL optimization event.
        # *   **ResourceOptimize**: storage optimization event.
        # 
        # Valid values of alert severities:
        # 
        # *   **info**
        # *   **noticed**
        # *   **warning**
        # *   **critical**
        self.severity = severity

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.active is not None:
            result['Active'] = self.active

        if self.channel_type is not None:
            result['ChannelType'] = self.channel_type

        if self.contact_group_name is not None:
            result['ContactGroupName'] = self.contact_group_name

        if self.contact_name is not None:
            result['ContactName'] = self.contact_name

        if self.dispatch_rule is not None:
            result['DispatchRule'] = self.dispatch_rule

        if self.event_context is not None:
            result['EventContext'] = self.event_context

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.lang is not None:
            result['Lang'] = self.lang

        if self.level is not None:
            result['Level'] = self.level

        if self.min_interval is not None:
            result['MinInterval'] = self.min_interval

        if self.severity is not None:
            result['Severity'] = self.severity

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Active') is not None:
            self.active = m.get('Active')

        if m.get('ChannelType') is not None:
            self.channel_type = m.get('ChannelType')

        if m.get('ContactGroupName') is not None:
            self.contact_group_name = m.get('ContactGroupName')

        if m.get('ContactName') is not None:
            self.contact_name = m.get('ContactName')

        if m.get('DispatchRule') is not None:
            self.dispatch_rule = m.get('DispatchRule')

        if m.get('EventContext') is not None:
            self.event_context = m.get('EventContext')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Lang') is not None:
            self.lang = m.get('Lang')

        if m.get('Level') is not None:
            self.level = m.get('Level')

        if m.get('MinInterval') is not None:
            self.min_interval = m.get('MinInterval')

        if m.get('Severity') is not None:
            self.severity = m.get('Severity')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class CreateCacheAnalysisJobResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.CreateCacheAnalysisJobResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The detailed information.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**: The request was successful.
        # *   **false**: The request failed.
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.CreateCacheAnalysisJobResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class CreateCacheAnalysisJobResponseBodyData(DaraModel):
    def __init__(
        self,
        big_keys: main_models.CreateCacheAnalysisJobResponseBodyDataBigKeys = None,
        instance_id: str = None,
        job_id: str = None,
        message: str = None,
        node_id: str = None,
        task_state: str = None,
    ):
        self.big_keys = big_keys
        # The instance ID.
        self.instance_id = instance_id
        # The ID of the cache analysis task.
        # 
        # >  This parameter can be used to query a specific cache analysis task. When you call the CreateCacheAnalysisJob operation, it takes some time to create a cache analysis task. As a result, the analysis results cannot be immediately returned. You can call the [DescribeCacheAnalysisJob](https://help.aliyun.com/document_detail/180983.html) operation to query the analysis results of the specified cache analysis task.
        self.job_id = job_id
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The ID of the data node on the instance.
        self.node_id = node_id
        # The state of the cache analysis task. Valid values:
        # 
        # *   **BACKUP**: The data is being backed up.
        # *   **ANALYZING**: The data is being analyzed.
        # *   **FINISHED**: The data is analyzed.
        # *   **FAILED**: An error occurred.
        self.task_state = task_state

    def validate(self):
        if self.big_keys:
            self.big_keys.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.big_keys is not None:
            result['BigKeys'] = self.big_keys.to_map()

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.job_id is not None:
            result['JobId'] = self.job_id

        if self.message is not None:
            result['Message'] = self.message

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.task_state is not None:
            result['TaskState'] = self.task_state

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('BigKeys') is not None:
            temp_model = main_models.CreateCacheAnalysisJobResponseBodyDataBigKeys()
            self.big_keys = temp_model.from_map(m.get('BigKeys'))

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('JobId') is not None:
            self.job_id = m.get('JobId')

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('TaskState') is not None:
            self.task_state = m.get('TaskState')

        return self

class CreateCacheAnalysisJobResponseBodyDataBigKeys(DaraModel):
    def __init__(
        self,
        key_info: List[main_models.CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo] = None,
    ):
        self.key_info = key_info

    def validate(self):
        if self.key_info:
            for v1 in self.key_info:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        result['KeyInfo'] = []
        if self.key_info is not None:
            for k1 in self.key_info:
                result['KeyInfo'].append(k1.to_map() if k1 else None)

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        self.key_info = []
        if m.get('KeyInfo') is not None:
            for k1 in m.get('KeyInfo'):
                temp_model = main_models.CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo()
                self.key_info.append(temp_model.from_map(k1))

        return self

class CreateCacheAnalysisJobResponseBodyDataBigKeysKeyInfo(DaraModel):
    def __init__(
        self,
        bytes: int = None,
        count: int = None,
        db: int = None,
        encoding: str = None,
        expiration_time_millis: int = None,
        key: str = None,
        node_id: str = None,
        type: str = None,
    ):
        self.bytes = bytes
        self.count = count
        self.db = db
        self.encoding = encoding
        self.expiration_time_millis = expiration_time_millis
        self.key = key
        self.node_id = node_id
        self.type = type

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.bytes is not None:
            result['Bytes'] = self.bytes

        if self.count is not None:
            result['Count'] = self.count

        if self.db is not None:
            result['Db'] = self.db

        if self.encoding is not None:
            result['Encoding'] = self.encoding

        if self.expiration_time_millis is not None:
            result['ExpirationTimeMillis'] = self.expiration_time_millis

        if self.key is not None:
            result['Key'] = self.key

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.type is not None:
            result['Type'] = self.type

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Bytes') is not None:
            self.bytes = m.get('Bytes')

        if m.get('Count') is not None:
            self.count = m.get('Count')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('Encoding') is not None:
            self.encoding = m.get('Encoding')

        if m.get('ExpirationTimeMillis') is not None:
            self.expiration_time_millis = m.get('ExpirationTimeMillis')

        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('Type') is not None:
            self.type = m.get('Type')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DisableAutoResourceOptimizeRulesResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: main_models.DisableAutoResourceOptimizeRulesResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DisableAutoResourceOptimizeRulesResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DisableAutoResourceOptimizeRulesResponseBodyData(DaraModel):
    def __init__(
        self,
        config_fail_instance_count: int = None,
        config_fail_instance_list: List[main_models.DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList] = None,
        config_success_instance_count: int = None,
        config_success_instance_list: List[main_models.DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList] = None,
        total_instance_count: int = None,
    ):
        # The number of database instances for which the automatic tablespace fragment recycling feature failed to be disabled.
        self.config_fail_instance_count = config_fail_instance_count
        # The list of database instances for which the automatic tablespace fragment recycling feature failed to be disabled.
        self.config_fail_instance_list = config_fail_instance_list
        # The number of database instances for which the automatic tablespace fragment recycling feature is disabled.
        self.config_success_instance_count = config_success_instance_count
        # The list of database instances for which the automatic tablespace fragment recycling feature is disabled.
        self.config_success_instance_list = config_success_instance_list
        # The total number of database instances.
        self.total_instance_count = total_instance_count

    def validate(self):
        if self.config_fail_instance_list:
            for v1 in self.config_fail_instance_list:
                 if v1:
                    v1.validate()
        if self.config_success_instance_list:
            for v1 in self.config_success_instance_list:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_fail_instance_count is not None:
            result['ConfigFailInstanceCount'] = self.config_fail_instance_count

        result['ConfigFailInstanceList'] = []
        if self.config_fail_instance_list is not None:
            for k1 in self.config_fail_instance_list:
                result['ConfigFailInstanceList'].append(k1.to_map() if k1 else None)

        if self.config_success_instance_count is not None:
            result['ConfigSuccessInstanceCount'] = self.config_success_instance_count

        result['ConfigSuccessInstanceList'] = []
        if self.config_success_instance_list is not None:
            for k1 in self.config_success_instance_list:
                result['ConfigSuccessInstanceList'].append(k1.to_map() if k1 else None)

        if self.total_instance_count is not None:
            result['TotalInstanceCount'] = self.total_instance_count

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConfigFailInstanceCount') is not None:
            self.config_fail_instance_count = m.get('ConfigFailInstanceCount')

        self.config_fail_instance_list = []
        if m.get('ConfigFailInstanceList') is not None:
            for k1 in m.get('ConfigFailInstanceList'):
                temp_model = main_models.DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList()
                self.config_fail_instance_list.append(temp_model.from_map(k1))

        if m.get('ConfigSuccessInstanceCount') is not None:
            self.config_success_instance_count = m.get('ConfigSuccessInstanceCount')

        self.config_success_instance_list = []
        if m.get('ConfigSuccessInstanceList') is not None:
            for k1 in m.get('ConfigSuccessInstanceList'):
                temp_model = main_models.DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList()
                self.config_success_instance_list.append(temp_model.from_map(k1))

        if m.get('TotalInstanceCount') is not None:
            self.total_instance_count = m.get('TotalInstanceCount')

        return self

class DisableAutoResourceOptimizeRulesResponseBodyDataConfigSuccessInstanceList(DaraModel):
    def __init__(
        self,
        config_success: bool = None,
        instance_id: str = None,
    ):
        # Indicates whether the automatic tablespace fragment recycling feature is disabled. Valid values:
        # 
        # * **true**
        # 
        # * **false**
        self.config_success = config_success
        # The database instance ID.
        self.instance_id = instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_success is not None:
            result['ConfigSuccess'] = self.config_success

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConfigSuccess') is not None:
            self.config_success = m.get('ConfigSuccess')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        return self

class DisableAutoResourceOptimizeRulesResponseBodyDataConfigFailInstanceList(DaraModel):
    def __init__(
        self,
        config_success: bool = None,
        error_message: str = None,
        instance_id: str = None,
    ):
        # Indicates whether the automatic tablespace fragment recycling feature is disabled. Valid values:
        # 
        # * **true**
        # 
        # * **false**
        self.config_success = config_success
        # The error message returned if the request failed.
        self.error_message = error_message
        # The database instance ID.
        self.instance_id = instance_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.config_success is not None:
            result['ConfigSuccess'] = self.config_success

        if self.error_message is not None:
            result['ErrorMessage'] = self.error_message

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('ConfigSuccess') is not None:
            self.config_success = m.get('ConfigSuccess')

        if m.get('ErrorMessage') is not None:
            self.error_message = m.get('ErrorMessage')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class GetPfsSqlSampleResponseBody(DaraModel):
    def __init__(
        self,
        code: int = None,
        data: List[main_models.GetPfsSqlSampleResponseBodyData] = None,
        message: str = None,
        request_id: str = None,
        success: bool = None,
    ):
        # The HTTP status code returned.
        self.code = code
        # The SQL sample data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**: The request was successful.
        # *   **false**: The request failed.
        self.success = success

    def validate(self):
        if self.data:
            for v1 in self.data:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        result['Data'] = []
        if self.data is not None:
            for k1 in self.data:
                result['Data'].append(k1.to_map() if k1 else None)

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        self.data = []
        if m.get('Data') is not None:
            for k1 in m.get('Data'):
                temp_model = main_models.GetPfsSqlSampleResponseBodyData()
                self.data.append(temp_model.from_map(k1))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class GetPfsSqlSampleResponseBodyData(DaraModel):
    def __init__(
        self,
        create_tmp_disk_tables: int = None,
        create_tmp_tables: int = None,
        db: str = None,
        end_event_id: int = None,
        errors: int = None,
        event_id: int = None,
        event_name: str = None,
        instance_id: str = None,
        latency: float = None,
        lock_latency: float = None,
        logic_id: str = None,
        no_good_index_used: int = None,
        no_index_used: int = None,
        node_id: str = None,
        rows_affected: int = None,
        rows_examined: int = None,
        rows_sent: int = None,
        select_full_join: int = None,
        select_full_range_join: int = None,
        select_range: int = None,
        select_range_check: int = None,
        select_scan: int = None,
        sort_merge_passes: int = None,
        sort_range: int = None,
        sort_rows: int = None,
        sort_scan: int = None,
        sql: str = None,
        sql_id: str = None,
        thread_id: int = None,
        timestamp: int = None,
        user_id: str = None,
        warnings: int = None,
    ):
        # The number of internal on-disk temporary tables that were created when the SQL statement was executed.
        self.create_tmp_disk_tables = create_tmp_disk_tables
        # The number of internal temporary tables that were created when the SQL statement was executed.
        self.create_tmp_tables = create_tmp_tables
        # The name of the database.
        self.db = db
        # The end ID of the event. By default, the value of this parameter is NULL when the event starts and is changed to the event ID when the event ends.
        self.end_event_id = end_event_id
        # The number of errors returned for the SQL statement.
        self.errors = errors
        # The event ID.
        self.event_id = event_id
        # The name of the event.
        self.event_name = event_name
        # The instance ID.
        self.instance_id = instance_id
        # The execution duration. Unit: millisecond.
        self.latency = latency
        # The lock wait duration. Unit: millisecond.
        self.lock_latency = lock_latency
        # The ID of the logical database.
        self.logic_id = logic_id
        # Indicates whether the server failed to find an index that can be used for the SQL statement. Valid values:
        # 
        # *   **1**: yes.
        # *   **0**: no.
        self.no_good_index_used = no_good_index_used
        # Indicates whether table scans were performed when indexes were not used. Valid values:
        # 
        # *   **1**: yes.
        # *   **0**: no.
        self.no_index_used = no_index_used
        # The node ID.
        # 
        # >  This parameter is returned only for ApsaraDB RDS for MySQL Cluster Edition instances or PolarDB for MySQL clusters.
        self.node_id = node_id
        # The number of rows affected by the SQL statement.
        self.rows_affected = rows_affected
        # The number of rows scanned by the SQL statement.
        self.rows_examined = rows_examined
        # The number of rows returned by the SQL statement.
        self.rows_sent = rows_sent
        # The number of joins that are used to perform table scans without using indexes.
        # 
        # > : This parameter is used for the scenario in which indexes are not used in a union query. If the returned value is not 0, check the indexes of tables.
        self.select_full_join = select_full_join
        # The number of joins that used ranges on referenced tables.
        self.select_full_range_join = select_full_range_join
        # The number of joins that used ranges on the first table.
        self.select_range = select_range
        # The number of joins that did not have key values. The keys and values were checked for each row of data.
        # 
        # > : This parameter is used for the scenario in which indexes are not used in a union query. If the returned value is not 0, check the indexes of tables.
        self.select_range_check = select_range_check
        # The number of scans.
        self.select_scan = select_scan
        # The number of merges that the sorting algorithm must perform.
        self.sort_merge_passes = sort_merge_passes
        # The number of times the data was sorted by using ranges.
        self.sort_range = sort_range
        # The number of sorted rows.
        self.sort_rows = sort_rows
        # The number of sorts that were performed during table scans.
        self.sort_scan = sort_scan
        # The sample SQL statement.
        self.sql = sql
        # The SQL statement ID.
        self.sql_id = sql_id
        # The thread ID.
        self.thread_id = thread_id
        # The time when the SQL statement was executed. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.timestamp = timestamp
        # The user ID.
        self.user_id = user_id
        # The number of warnings returned for the SQL statement.
        self.warnings = warnings

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_tmp_disk_tables is not None:
            result['CreateTmpDiskTables'] = self.create_tmp_disk_tables

        if self.create_tmp_tables is not None:
            result['CreateTmpTables'] = self.create_tmp_tables

        if self.db is not None:
            result['Db'] = self.db

        if self.end_event_id is not None:
            result['EndEventId'] = self.end_event_id

        if self.errors is not None:
            result['Errors'] = self.errors

        if self.event_id is not None:
            result['EventId'] = self.event_id

        if self.event_name is not None:
            result['EventName'] = self.event_name

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.latency is not None:
            result['Latency'] = self.latency

        if self.lock_latency is not None:
            result['LockLatency'] = self.lock_latency

        if self.logic_id is not None:
            result['LogicId'] = self.logic_id

        if self.no_good_index_used is not None:
            result['NoGoodIndexUsed'] = self.no_good_index_used

        if self.no_index_used is not None:
            result['NoIndexUsed'] = self.no_index_used

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.rows_affected is not None:
            result['RowsAffected'] = self.rows_affected

        if self.rows_examined is not None:
            result['RowsExamined'] = self.rows_examined

        if self.rows_sent is not None:
            result['RowsSent'] = self.rows_sent

        if self.select_full_join is not None:
            result['SelectFullJoin'] = self.select_full_join

        if self.select_full_range_join is not None:
            result['SelectFullRangeJoin'] = self.select_full_range_join

        if self.select_range is not None:
            result['SelectRange'] = self.select_range

        if self.select_range_check is not None:
            result['SelectRangeCheck'] = self.select_range_check

        if self.select_scan is not None:
            result['SelectScan'] = self.select_scan

        if self.sort_merge_passes is not None:
            result['SortMergePasses'] = self.sort_merge_passes

        if self.sort_range is not None:
            result['SortRange'] = self.sort_range

        if self.sort_rows is not None:
            result['SortRows'] = self.sort_rows

        if self.sort_scan is not None:
            result['SortScan'] = self.sort_scan

        if self.sql is not None:
            result['Sql'] = self.sql

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.thread_id is not None:
            result['ThreadId'] = self.thread_id

        if self.timestamp is not None:
            result['Timestamp'] = self.timestamp

        if self.user_id is not None:
            result['UserId'] = self.user_id

        if self.warnings is not None:
            result['Warnings'] = self.warnings

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTmpDiskTables') is not None:
            self.create_tmp_disk_tables = m.get('CreateTmpDiskTables')

        if m.get('CreateTmpTables') is not None:
            self.create_tmp_tables = m.get('CreateTmpTables')

        if m.get('Db') is not None:
            self.db = m.get('Db')

        if m.get('EndEventId') is not None:
            self.end_event_id = m.get('EndEventId')

        if m.get('Errors') is not None:
            self.errors = m.get('Errors')

        if m.get('EventId') is not None:
            self.event_id = m.get('EventId')

        if m.get('EventName') is not None:
            self.event_name = m.get('EventName')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Latency') is not None:
            self.latency = m.get('Latency')

        if m.get('LockLatency') is not None:
            self.lock_latency = m.get('LockLatency')

        if m.get('LogicId') is not None:
            self.logic_id = m.get('LogicId')

        if m.get('NoGoodIndexUsed') is not None:
            self.no_good_index_used = m.get('NoGoodIndexUsed')

        if m.get('NoIndexUsed') is not None:
            self.no_index_used = m.get('NoIndexUsed')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('RowsAffected') is not None:
            self.rows_affected = m.get('RowsAffected')

        if m.get('RowsExamined') is not None:
            self.rows_examined = m.get('RowsExamined')

        if m.get('RowsSent') is not None:
            self.rows_sent = m.get('RowsSent')

        if m.get('SelectFullJoin') is not None:
            self.select_full_join = m.get('SelectFullJoin')

        if m.get('SelectFullRangeJoin') is not None:
            self.select_full_range_join = m.get('SelectFullRangeJoin')

        if m.get('SelectRange') is not None:
            self.select_range = m.get('SelectRange')

        if m.get('SelectRangeCheck') is not None:
            self.select_range_check = m.get('SelectRangeCheck')

        if m.get('SelectScan') is not None:
            self.select_scan = m.get('SelectScan')

        if m.get('SortMergePasses') is not None:
            self.sort_merge_passes = m.get('SortMergePasses')

        if m.get('SortRange') is not None:
            self.sort_range = m.get('SortRange')

        if m.get('SortRows') is not None:
            self.sort_rows = m.get('SortRows')

        if m.get('SortScan') is not None:
            self.sort_scan = m.get('SortScan')

        if m.get('Sql') is not None:
            self.sql = m.get('Sql')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('ThreadId') is not None:
            self.thread_id = m.get('ThreadId')

        if m.get('Timestamp') is not None:
            self.timestamp = m.get('Timestamp')

        if m.get('UserId') is not None:
            self.user_id = m.get('UserId')

        if m.get('Warnings') is not None:
            self.warnings = m.get('Warnings')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class AddHDMInstanceRequest(DaraModel):
    def __init__(
        self,
        engine: str = None,
        flush_account: str = None,
        instance_alias: str = None,
        instance_area: str = None,
        instance_id: str = None,
        ip: str = None,
        network_type: str = None,
        password: str = None,
        port: str = None,
        region: str = None,
        username: str = None,
        vpc_id: str = None,
        context: str = None,
    ):
        # The database engine. Valid values:
        # 
        # *   **MySQL**
        # *   **PostgreSQL**
        # *   **SQLServer**
        # *   **PolarDBMySQL**
        # *   **PolarDBPostgreSQL**
        # *   **Redis**
        # *   **MongoDB**
        # *   **PolarDBOracle**
        # *   **PolarDBX**
        self.engine = engine
        # The reserved parameter.
        self.flush_account = flush_account
        # The name of the instance.
        self.instance_alias = instance_alias
        # The type of the instance on which the database is deployed. Valid values:
        # 
        # *   **RDS**: an Alibaba Cloud database instance.
        # *   **ECS**: an Elastic Compute Service (ECS) instance on which a self-managed database is deployed.
        # *   **IDC**: a self-managed database instance that is not deployed on Alibaba Cloud.
        # 
        # >  IDC refers to your data center.
        # 
        # This parameter is required.
        self.instance_area = instance_area
        # The instance ID.
        self.instance_id = instance_id
        # The endpoint that is used to access the instance over internal networks.
        self.ip = ip
        # The network type of the instance.
        self.network_type = network_type
        # The password for the username.
        self.password = password
        # The port that is used to access the instance over internal networks.
        self.port = port
        # The ID of the region in which the instance resides.
        self.region = region
        # The username that is used to log on to the database.
        self.username = username
        # The virtual private cloud (VPC) ID.
        self.vpc_id = vpc_id
        # The reserved parameter.
        self.context = context

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.engine is not None:
            result['Engine'] = self.engine

        if self.flush_account is not None:
            result['FlushAccount'] = self.flush_account

        if self.instance_alias is not None:
            result['InstanceAlias'] = self.instance_alias

        if self.instance_area is not None:
            result['InstanceArea'] = self.instance_area

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.ip is not None:
            result['Ip'] = self.ip

        if self.network_type is not None:
            result['NetworkType'] = self.network_type

        if self.password is not None:
            result['Password'] = self.password

        if self.port is not None:
            result['Port'] = self.port

        if self.region is not None:
            result['Region'] = self.region

        if self.username is not None:
            result['Username'] = self.username

        if self.vpc_id is not None:
            result['VpcId'] = self.vpc_id

        if self.context is not None:
            result['__context'] = self.context

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Engine') is not None:
            self.engine = m.get('Engine')

        if m.get('FlushAccount') is not None:
            self.flush_account = m.get('FlushAccount')

        if m.get('InstanceAlias') is not None:
            self.instance_alias = m.get('InstanceAlias')

        if m.get('InstanceArea') is not None:
            self.instance_area = m.get('InstanceArea')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Ip') is not None:
            self.ip = m.get('Ip')

        if m.get('NetworkType') is not None:
            self.network_type = m.get('NetworkType')

        if m.get('Password') is not None:
            self.password = m.get('Password')

        if m.get('Port') is not None:
            self.port = m.get('Port')

        if m.get('Region') is not None:
            self.region = m.get('Region')

        if m.get('Username') is not None:
            self.username = m.get('Username')

        if m.get('VpcId') is not None:
            self.vpc_id = m.get('VpcId')

        if m.get('__context') is not None:
            self.context = m.get('__context')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from darabonba.model import DaraModel

class CreateQueryOptimizeTagRequest(DaraModel):
    def __init__(
        self,
        comments: str = None,
        engine: str = None,
        instance_id: str = None,
        sql_ids: str = None,
        status: int = None,
        tags: str = None,
    ):
        # The remarks.
        # 
        # The remarks can be 1 to 300 characters in length.
        self.comments = comments
        # The database engine. Valid values:
        # 
        # *   **MySQL**: ApsaraDB RDS for MySQL
        # *   **PolarDBMySQL**: PolarDB for MySQL
        # *   **PostgreSQL**: ApsaraDB RDS for PostgreSQL
        # 
        # This parameter is required.
        self.engine = engine
        # The instance ID.
        # 
        # This parameter is required.
        self.instance_id = instance_id
        # The SQL template IDs. You can call the [GetQueryOptimizeExecErrorStats](https://help.aliyun.com/document_detail/405261.html) operation to obtain the SQL template ID. Separate multiple SQL template IDs with commas (,).
        # 
        # This parameter is required.
        self.sql_ids = sql_ids
        # The status of **Tags**. Valid values:
        # 
        # *   **0**: removes all tags added to the SQL templates that are specified by **SqlIds** and leaves **Tags** empty.
        # *   **1**: adds the tags specified by **Tags** to the SQL templates that are specified by **SqlIds**.
        # 
        # This parameter is required.
        self.status = status
        # The SQL tags. Separate multiple SQL tags with commas (,). Valid values:
        # 
        # *   **DAS_IMPORTANT**: The SQL template is important.
        # *   **DAS_NOT_IMPORTANT**: The SQL template is unimportant.
        # *   **USER_IGNORE**: The scheduling of the SQL template does not need to be optimized.
        # *   **DAS_IN_PLAN**: The scheduling of the SQL template needs to be optimized.
        # 
        # This parameter is required.
        self.tags = tags

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.comments is not None:
            result['Comments'] = self.comments

        if self.engine is not None:
            result['Engine'] = self.engine

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.sql_ids is not None:
            result['SqlIds'] = self.sql_ids

        if self.status is not None:
            result['Status'] = self.status

        if self.tags is not None:
            result['Tags'] = self.tags

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Comments') is not None:
            self.comments = m.get('Comments')

        if m.get('Engine') is not None:
            self.engine = m.get('Engine')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('SqlIds') is not None:
            self.sql_ids = m.get('SqlIds')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('Tags') is not None:
            self.tags = m.get('Tags')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from typing import List, Any

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class DescribeSqlLogTaskResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.DescribeSqlLogTaskResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The response code.
        self.code = code
        # The data returned.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, an error message is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.DescribeSqlLogTaskResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class DescribeSqlLogTaskResponseBodyData(DaraModel):
    def __init__(
        self,
        create_time: int = None,
        end: int = None,
        expire: bool = None,
        export: str = None,
        filters: List[main_models.DescribeSqlLogTaskResponseBodyDataFilters] = None,
        name: str = None,
        queries: List[main_models.DescribeSqlLogTaskResponseBodyDataQueries] = None,
        start: int = None,
        status: str = None,
        task_id: str = None,
        task_type: str = None,
        total: int = None,
    ):
        # The time when the task was created. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.create_time = create_time
        # The end of the time range to query. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.end = end
        # Indicates whether the task has expired. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.expire = expire
        # The download URL of the export task.
        self.export = export
        # The filter parameters.
        self.filters = filters
        # The task name.
        self.name = name
        # The results of the offline querying task.
        self.queries = queries
        # The beginning of the time range to query. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start = start
        # The task state. Valid values:
        # 
        # *   **INIT**: The task is to be scheduled.
        # *   **RUNNING**: The task is running.
        # *   **FAILED**: The task failed.
        # *   **CANCELED**: The task is canceled.
        # *   **COMPLETED**: The task is complete.
        # 
        # >  If a task is in the **COMPLETED** state, you can view the results of the task.
        self.status = status
        # The task ID.
        self.task_id = task_id
        # The task type. Valid values:
        # 
        # *   **Export**
        # *   **Query**
        self.task_type = task_type
        # The total number of tasks.
        self.total = total

    def validate(self):
        if self.filters:
            for v1 in self.filters:
                 if v1:
                    v1.validate()
        if self.queries:
            for v1 in self.queries:
                 if v1:
                    v1.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        if self.end is not None:
            result['End'] = self.end

        if self.expire is not None:
            result['Expire'] = self.expire

        if self.export is not None:
            result['Export'] = self.export

        result['Filters'] = []
        if self.filters is not None:
            for k1 in self.filters:
                result['Filters'].append(k1.to_map() if k1 else None)

        if self.name is not None:
            result['Name'] = self.name

        result['Queries'] = []
        if self.queries is not None:
            for k1 in self.queries:
                result['Queries'].append(k1.to_map() if k1 else None)

        if self.start is not None:
            result['Start'] = self.start

        if self.status is not None:
            result['Status'] = self.status

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        if self.task_type is not None:
            result['TaskType'] = self.task_type

        if self.total is not None:
            result['Total'] = self.total

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        if m.get('End') is not None:
            self.end = m.get('End')

        if m.get('Expire') is not None:
            self.expire = m.get('Expire')

        if m.get('Export') is not None:
            self.export = m.get('Export')

        self.filters = []
        if m.get('Filters') is not None:
            for k1 in m.get('Filters'):
                temp_model = main_models.DescribeSqlLogTaskResponseBodyDataFilters()
                self.filters.append(temp_model.from_map(k1))

        if m.get('Name') is not None:
            self.name = m.get('Name')

        self.queries = []
        if m.get('Queries') is not None:
            for k1 in m.get('Queries'):
                temp_model = main_models.DescribeSqlLogTaskResponseBodyDataQueries()
                self.queries.append(temp_model.from_map(k1))

        if m.get('Start') is not None:
            self.start = m.get('Start')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        if m.get('TaskType') is not None:
            self.task_type = m.get('TaskType')

        if m.get('Total') is not None:
            self.total = m.get('Total')

        return self

class DescribeSqlLogTaskResponseBodyDataQueries(DaraModel):
    def __init__(
        self,
        account_name: str = None,
        affect_columns: str = None,
        client_ip: str = None,
        client_port: int = None,
        collection: str = None,
        connection_id: str = None,
        consume: int = None,
        cpu_time: int = None,
        dbname: str = None,
        execute_time: str = None,
        ext: str = None,
        frows: int = None,
        host_address: str = None,
        lock_time: int = None,
        logic_read: int = None,
        node_id: str = None,
        origin_time: int = None,
        parallel_degree: str = None,
        parallel_queue_time: str = None,
        params: str = None,
        physic_async_read: int = None,
        physic_read: int = None,
        physic_sync_read: int = None,
        protected: str = None,
        return_rows: int = None,
        row_key: str = None,
        rows: int = None,
        scan_rows: int = None,
        scnt: int = None,
        sql_command: int = None,
        sql_id: str = None,
        sql_text: str = None,
        sql_type: str = None,
        state: str = None,
        table_name: str = None,
        thread_id: int = None,
        trace_id: str = None,
        trx_id: str = None,
        update_rows: int = None,
        use_imci_engine: str = None,
        vip: str = None,
        writes: int = None,
    ):
        # The database account.
        self.account_name = account_name
        self.affect_columns = affect_columns
        self.client_ip = client_ip
        self.client_port = client_port
        self.collection = collection
        self.connection_id = connection_id
        # The execution duration. Unit: millisecond.
        self.consume = consume
        # The CPU execution time. Unit: microsecond.
        self.cpu_time = cpu_time
        # The database name.
        self.dbname = dbname
        # The execution time. The time follows the ISO 8601 standard in the `yyyy-MM-ddTHH:mm:ssZ` format. The time is displayed in UTC.
        self.execute_time = execute_time
        # The extended information. This parameter is a reserved parameter.
        self.ext = ext
        # The number of rows pulled by the CNs of the PolarDB-X 2.0 instance.
        self.frows = frows
        # The IP address of the client.
        self.host_address = host_address
        # The lock wait time. Unit: millisecond.
        self.lock_time = lock_time
        # The number of logical reads.
        self.logic_read = logic_read
        # The ID of the child node.
        self.node_id = node_id
        # The execution timestamp. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.origin_time = origin_time
        # The wait time of parallel queries in the queue in the PolarDB for MySQL instance. Unit: millisecond.
        self.parallel_degree = parallel_degree
        # The degree of parallelism (DOP) value of the PolarDB for MySQL instance.
        self.parallel_queue_time = parallel_queue_time
        self.params = params
        # The number of physical asynchronous reads.
        self.physic_async_read = physic_async_read
        # The total number of physical reads.
        self.physic_read = physic_read
        # The number of physical synchronous reads.
        self.physic_sync_read = physic_sync_read
        self.protected = protected
        # The number of rows returned.
        self.return_rows = return_rows
        self.row_key = row_key
        # The total number of rows updated or returned by the CNs of the PolarDB-X 2.0 instance.
        self.rows = rows
        # The number of rows scanned.
        self.scan_rows = scan_rows
        # The number of requests from the compute nodes (CNs) to the data nodes (DNs) in the PolarDB-X 2.0 instance.
        self.scnt = scnt
        self.sql_command = sql_command
        # The ID of the SQL statement.
        self.sql_id = sql_id
        # The queried SQL statement.
        self.sql_text = sql_text
        # The type of the SQL statement. Valid values:
        # 
        # *   **SELECT**
        # *   **UPDATE**
        # *   **DELETE**
        self.sql_type = sql_type
        # The execution result of the SQL statement. Valid values:
        # 
        # *   **0**: The execution was successful.
        # *   **1**: The execution failed.
        self.state = state
        self.table_name = table_name
        # The thread ID.
        self.thread_id = thread_id
        # The trace ID of the PolarDB-X 2.0 instance, which is the execution ID of the SQL statement on the DN.
        self.trace_id = trace_id
        # The transaction ID.
        self.trx_id = trx_id
        # The number of rows updated.
        self.update_rows = update_rows
        # Indicates whether the PolarDB for MySQL instance uses In-Memory Column Indexes (IMCIs). Valid values:
        # 
        # *   **true**
        # *   **false**
        self.use_imci_engine = use_imci_engine
        # The IP address to which the endpoint used for query is resolved.
        self.vip = vip
        # The number of writes to the ApsaraDB RDS for SQL Server instance.
        self.writes = writes

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.account_name is not None:
            result['AccountName'] = self.account_name

        if self.affect_columns is not None:
            result['AffectColumns'] = self.affect_columns

        if self.client_ip is not None:
            result['ClientIp'] = self.client_ip

        if self.client_port is not None:
            result['ClientPort'] = self.client_port

        if self.collection is not None:
            result['Collection'] = self.collection

        if self.connection_id is not None:
            result['ConnectionId'] = self.connection_id

        if self.consume is not None:
            result['Consume'] = self.consume

        if self.cpu_time is not None:
            result['CpuTime'] = self.cpu_time

        if self.dbname is not None:
            result['DBName'] = self.dbname

        if self.execute_time is not None:
            result['ExecuteTime'] = self.execute_time

        if self.ext is not None:
            result['Ext'] = self.ext

        if self.frows is not None:
            result['Frows'] = self.frows

        if self.host_address is not None:
            result['HostAddress'] = self.host_address

        if self.lock_time is not None:
            result['LockTime'] = self.lock_time

        if self.logic_read is not None:
            result['LogicRead'] = self.logic_read

        if self.node_id is not None:
            result['NodeId'] = self.node_id

        if self.origin_time is not None:
            result['OriginTime'] = self.origin_time

        if self.parallel_degree is not None:
            result['ParallelDegree'] = self.parallel_degree

        if self.parallel_queue_time is not None:
            result['ParallelQueueTime'] = self.parallel_queue_time

        if self.params is not None:
            result['Params'] = self.params

        if self.physic_async_read is not None:
            result['PhysicAsyncRead'] = self.physic_async_read

        if self.physic_read is not None:
            result['PhysicRead'] = self.physic_read

        if self.physic_sync_read is not None:
            result['PhysicSyncRead'] = self.physic_sync_read

        if self.protected is not None:
            result['Protected'] = self.protected

        if self.return_rows is not None:
            result['ReturnRows'] = self.return_rows

        if self.row_key is not None:
            result['RowKey'] = self.row_key

        if self.rows is not None:
            result['Rows'] = self.rows

        if self.scan_rows is not None:
            result['ScanRows'] = self.scan_rows

        if self.scnt is not None:
            result['Scnt'] = self.scnt

        if self.sql_command is not None:
            result['SqlCommand'] = self.sql_command

        if self.sql_id is not None:
            result['SqlId'] = self.sql_id

        if self.sql_text is not None:
            result['SqlText'] = self.sql_text

        if self.sql_type is not None:
            result['SqlType'] = self.sql_type

        if self.state is not None:
            result['State'] = self.state

        if self.table_name is not None:
            result['TableName'] = self.table_name

        if self.thread_id is not None:
            result['ThreadId'] = self.thread_id

        if self.trace_id is not None:
            result['TraceId'] = self.trace_id

        if self.trx_id is not None:
            result['TrxId'] = self.trx_id

        if self.update_rows is not None:
            result['UpdateRows'] = self.update_rows

        if self.use_imci_engine is not None:
            result['UseImciEngine'] = self.use_imci_engine

        if self.vip is not None:
            result['Vip'] = self.vip

        if self.writes is not None:
            result['Writes'] = self.writes

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('AccountName') is not None:
            self.account_name = m.get('AccountName')

        if m.get('AffectColumns') is not None:
            self.affect_columns = m.get('AffectColumns')

        if m.get('ClientIp') is not None:
            self.client_ip = m.get('ClientIp')

        if m.get('ClientPort') is not None:
            self.client_port = m.get('ClientPort')

        if m.get('Collection') is not None:
            self.collection = m.get('Collection')

        if m.get('ConnectionId') is not None:
            self.connection_id = m.get('ConnectionId')

        if m.get('Consume') is not None:
            self.consume = m.get('Consume')

        if m.get('CpuTime') is not None:
            self.cpu_time = m.get('CpuTime')

        if m.get('DBName') is not None:
            self.dbname = m.get('DBName')

        if m.get('ExecuteTime') is not None:
            self.execute_time = m.get('ExecuteTime')

        if m.get('Ext') is not None:
            self.ext = m.get('Ext')

        if m.get('Frows') is not None:
            self.frows = m.get('Frows')

        if m.get('HostAddress') is not None:
            self.host_address = m.get('HostAddress')

        if m.get('LockTime') is not None:
            self.lock_time = m.get('LockTime')

        if m.get('LogicRead') is not None:
            self.logic_read = m.get('LogicRead')

        if m.get('NodeId') is not None:
            self.node_id = m.get('NodeId')

        if m.get('OriginTime') is not None:
            self.origin_time = m.get('OriginTime')

        if m.get('ParallelDegree') is not None:
            self.parallel_degree = m.get('ParallelDegree')

        if m.get('ParallelQueueTime') is not None:
            self.parallel_queue_time = m.get('ParallelQueueTime')

        if m.get('Params') is not None:
            self.params = m.get('Params')

        if m.get('PhysicAsyncRead') is not None:
            self.physic_async_read = m.get('PhysicAsyncRead')

        if m.get('PhysicRead') is not None:
            self.physic_read = m.get('PhysicRead')

        if m.get('PhysicSyncRead') is not None:
            self.physic_sync_read = m.get('PhysicSyncRead')

        if m.get('Protected') is not None:
            self.protected = m.get('Protected')

        if m.get('ReturnRows') is not None:
            self.return_rows = m.get('ReturnRows')

        if m.get('RowKey') is not None:
            self.row_key = m.get('RowKey')

        if m.get('Rows') is not None:
            self.rows = m.get('Rows')

        if m.get('ScanRows') is not None:
            self.scan_rows = m.get('ScanRows')

        if m.get('Scnt') is not None:
            self.scnt = m.get('Scnt')

        if m.get('SqlCommand') is not None:
            self.sql_command = m.get('SqlCommand')

        if m.get('SqlId') is not None:
            self.sql_id = m.get('SqlId')

        if m.get('SqlText') is not None:
            self.sql_text = m.get('SqlText')

        if m.get('SqlType') is not None:
            self.sql_type = m.get('SqlType')

        if m.get('State') is not None:
            self.state = m.get('State')

        if m.get('TableName') is not None:
            self.table_name = m.get('TableName')

        if m.get('ThreadId') is not None:
            self.thread_id = m.get('ThreadId')

        if m.get('TraceId') is not None:
            self.trace_id = m.get('TraceId')

        if m.get('TrxId') is not None:
            self.trx_id = m.get('TrxId')

        if m.get('UpdateRows') is not None:
            self.update_rows = m.get('UpdateRows')

        if m.get('UseImciEngine') is not None:
            self.use_imci_engine = m.get('UseImciEngine')

        if m.get('Vip') is not None:
            self.vip = m.get('Vip')

        if m.get('Writes') is not None:
            self.writes = m.get('Writes')

        return self

class DescribeSqlLogTaskResponseBodyDataFilters(DaraModel):
    def __init__(
        self,
        key: str = None,
        value: Any = None,
    ):
        # The name of the filter parameter.
        # 
        # >  For more information about the filter parameters, see the **Valid values of Key** section of this topic.
        self.key = key
        # The value of the filter parameter.
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.key is not None:
            result['Key'] = self.key

        if self.value is not None:
            result['Value'] = self.value

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Key') is not None:
            self.key = m.get('Key')

        if m.get('Value') is not None:
            self.value = m.get('Value')

        return self




# -*- coding: utf-8 -*-
# This file is auto-generated, don't edit it. Thanks.
from __future__ import annotations

from alibabacloud_das20200116 import models as main_models
from darabonba.model import DaraModel

class CreateSqlLogTaskResponseBody(DaraModel):
    def __init__(
        self,
        code: str = None,
        data: main_models.CreateSqlLogTaskResponseBodyData = None,
        message: str = None,
        request_id: str = None,
        success: str = None,
    ):
        # The response code.
        self.code = code
        # The returned data.
        self.data = data
        # The returned message.
        # 
        # >  If the request was successful, **Successful** is returned. If the request failed, error information such as an error code is returned.
        self.message = message
        # The request ID.
        self.request_id = request_id
        # Indicates whether the request was successful. Valid values:
        # 
        # *   **true**
        # *   **false**
        self.success = success

    def validate(self):
        if self.data:
            self.data.validate()

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.code is not None:
            result['Code'] = self.code

        if self.data is not None:
            result['Data'] = self.data.to_map()

        if self.message is not None:
            result['Message'] = self.message

        if self.request_id is not None:
            result['RequestId'] = self.request_id

        if self.success is not None:
            result['Success'] = self.success

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('Code') is not None:
            self.code = m.get('Code')

        if m.get('Data') is not None:
            temp_model = main_models.CreateSqlLogTaskResponseBodyData()
            self.data = temp_model.from_map(m.get('Data'))

        if m.get('Message') is not None:
            self.message = m.get('Message')

        if m.get('RequestId') is not None:
            self.request_id = m.get('RequestId')

        if m.get('Success') is not None:
            self.success = m.get('Success')

        return self

class CreateSqlLogTaskResponseBodyData(DaraModel):
    def __init__(
        self,
        create_time: int = None,
        end: int = None,
        instance_id: str = None,
        name: str = None,
        start: int = None,
        status: str = None,
        task_id: str = None,
    ):
        # The time when the task was created. This value is a UNIX timestamp. Unit: milliseconds.
        self.create_time = create_time
        # The end of the time range to query. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.end = end
        # The ID of the database instance.
        self.instance_id = instance_id
        # The name of the task.
        self.name = name
        # The beginning of the time range to query. This value is a UNIX timestamp representing the number of milliseconds that have elapsed since January 1, 1970, 00:00:00 UTC.
        self.start = start
        # The state of the task. Valid values:
        # 
        # *   **INIT**: The task is to be scheduled.
        # *   **RUNNING**: The task is running.
        # *   **FAILED**: The task failed.
        # *   **CANCELED**: The task is canceled.
        # *   **COMPLETED**: The task is complete.
        # 
        # >  You can view the result of a task that is in the **COMPLETED** state.
        self.status = status
        # The task ID.
        self.task_id = task_id

    def validate(self):
        pass

    def to_map(self):
        result = dict()
        _map = super().to_map()
        if _map is not None:
            result = _map
        if self.create_time is not None:
            result['CreateTime'] = self.create_time

        if self.end is not None:
            result['End'] = self.end

        if self.instance_id is not None:
            result['InstanceId'] = self.instance_id

        if self.name is not None:
            result['Name'] = self.name

        if self.start is not None:
            result['Start'] = self.start

        if self.status is not None:
            result['Status'] = self.status

        if self.task_id is not None:
            result['TaskId'] = self.task_id

        return result

    def from_map(self, m: dict = None):
        m = m or dict()
        if m.get('CreateTime') is not None:
            self.create_time = m.get('CreateTime')

        if m.get('End') is not None:
            self.end = m.get('End')

        if m.get('InstanceId') is not None:
            self.instance_id = m.get('InstanceId')

        if m.get('Name') is not None:
            self.name = m.get('Name')

        if m.get('Start') is not None:
            self.start = m.get('Start')

        if m.get('Status') is not None:
            self.status = m.get('Status')

        if m.get('TaskId') is not None:
            self.task_id = m.get('TaskId')

        return self

